@@ -93,11 +93,11 @@ GtkamlClassDefinition* gtkaml_class_definition_new (ValaSourceReference* source_
 	gtkaml_class_definition_set_definition_scope (self, definition_scope);
 	gtkaml_class_definition_set_parent_container (self, parent_container);
 	_tmp0 = NULL;
-	gtkaml_class_definition_set_attrs (self, GEE_LIST ((_tmp0 = gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal))));
+	gtkaml_class_definition_set_attrs (self, GEE_LIST ((_tmp0 = gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal))));
 	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
 	gtkaml_class_definition_set_construct_method (self, NULL);
 	_tmp1 = NULL;
-	gtkaml_class_definition_set_children (self, GEE_LIST ((_tmp1 = gee_array_list_new (GTKAML_TYPE_CLASS_DEFINITION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal))));
+	gtkaml_class_definition_set_children (self, GEE_LIST ((_tmp1 = gee_array_list_new (GTKAML_TYPE_CLASS_DEFINITION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal))));
 	(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
 	gtkaml_class_definition_set_construct_code (self, NULL);
 	gtkaml_class_definition_set_preconstruct_code (self, NULL);
@@ -135,7 +135,7 @@ void gtkaml_class_definition_set_source_reference (GtkamlClassDefinition* self,
 }
 
 
-char* gtkaml_class_definition_get_identifier (GtkamlClassDefinition* self) {
+const char* gtkaml_class_definition_get_identifier (GtkamlClassDefinition* self) {
 	g_return_val_if_fail (GTKAML_IS_CLASS_DEFINITION (self), NULL);
 	return self->priv->_identifier;
 }
@@ -152,17 +152,30 @@ void gtkaml_class_definition_set_identifier (GtkamlClassDefinition* self, const
 
 
 char* gtkaml_class_definition_get_base_full_name (GtkamlClassDefinition* self) {
-	char* _tmp0;
-	char* _tmp1;
+	char* baseful_name;
 	g_return_val_if_fail (GTKAML_IS_CLASS_DEFINITION (self), NULL);
-	/*BUG return (ns == null)? base_type.name : ns + "." + base_type.name;*/
-	_tmp0 = NULL;
-	_tmp1 = NULL;
-	return (_tmp1 = ((self->priv->_base_ns == NULL) ? vala_symbol_get_name (VALA_SYMBOL (self->priv->_base_type)) : (g_strconcat ((_tmp0 = g_strconcat (self->priv->_base_ns, ".", NULL)), vala_symbol_get_name (VALA_SYMBOL (self->priv->_base_type)), NULL))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	/*BUG return (ns == null)? base_type.name : ns + "." + base_type.name;
+	BUG return (base_ns == null)? base_type.name : (base_ns + "." + base_type.name);*/
+	baseful_name = NULL;
+	if (self->priv->_base_ns == NULL) {
+		char* _tmp1;
+		const char* _tmp0;
+		_tmp1 = NULL;
+		_tmp0 = NULL;
+		baseful_name = (_tmp1 = (_tmp0 = vala_symbol_get_name (VALA_SYMBOL (self->priv->_base_type)), (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (baseful_name = (g_free (baseful_name), NULL)), _tmp1);
+	} else {
+		char* _tmp3;
+		char* _tmp2;
+		_tmp3 = NULL;
+		_tmp2 = NULL;
+		baseful_name = (_tmp3 = g_strconcat ((_tmp2 = g_strconcat (self->priv->_base_ns, ".", NULL)), vala_symbol_get_name (VALA_SYMBOL (self->priv->_base_type)), NULL), (baseful_name = (g_free (baseful_name), NULL)), _tmp3);
+		_tmp2 = (g_free (_tmp2), NULL);
+	}
+	return baseful_name;
 }
 
 
-char* gtkaml_class_definition_get_base_ns (GtkamlClassDefinition* self) {
+const char* gtkaml_class_definition_get_base_ns (GtkamlClassDefinition* self) {
 	g_return_val_if_fail (GTKAML_IS_CLASS_DEFINITION (self), NULL);
 	return self->priv->_base_ns;
 }
@@ -282,7 +295,7 @@ void gtkaml_class_definition_set_add_method (GtkamlClassDefinition* self, Gtkaml
 }
 
 
-char* gtkaml_class_definition_get_construct_code (GtkamlClassDefinition* self) {
+const char* gtkaml_class_definition_get_construct_code (GtkamlClassDefinition* self) {
 	g_return_val_if_fail (GTKAML_IS_CLASS_DEFINITION (self), NULL);
 	return self->priv->_construct_code;
 }
@@ -298,7 +311,7 @@ void gtkaml_class_definition_set_construct_code (GtkamlClassDefinition* self, co
 }
 
 
-char* gtkaml_class_definition_get_preconstruct_code (GtkamlClassDefinition* self) {
+const char* gtkaml_class_definition_get_preconstruct_code (GtkamlClassDefinition* self) {
 	g_return_val_if_fail (GTKAML_IS_CLASS_DEFINITION (self), NULL);
 	return self->priv->_preconstruct_code;
 }
@@ -433,7 +446,7 @@ static void gtkaml_class_definition_class_init (GtkamlClassDefinitionClass * kla
 }
 
 
-static void gtkaml_class_definition_init (GtkamlClassDefinition * self) {
+static void gtkaml_class_definition_instance_init (GtkamlClassDefinition * self) {
 	self->priv = GTKAML_CLASS_DEFINITION_GET_PRIVATE (self);
 }
 
@@ -458,7 +471,7 @@ static void gtkaml_class_definition_dispose (GObject * obj) {
 GType gtkaml_class_definition_get_type (void) {
 	static GType gtkaml_class_definition_type_id = 0;
 	if (G_UNLIKELY (gtkaml_class_definition_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GtkamlClassDefinitionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_class_definition_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlClassDefinition), 0, (GInstanceInitFunc) gtkaml_class_definition_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GtkamlClassDefinitionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_class_definition_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlClassDefinition), 0, (GInstanceInitFunc) gtkaml_class_definition_instance_init };
 		gtkaml_class_definition_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlClassDefinition", &g_define_type_info, 0);
 	}
 	return gtkaml_class_definition_type_id;
