@@ -160,7 +160,7 @@ void gtkaml_code_generator_generate (GtkamlCodeGenerator* self, GtkamlClassDefin
 	if (GTKAML_IS_ROOT_CLASS_DEFINITION (class_definition)) {
 		GtkamlClassDefinition* _tmp0;
 		_tmp0 = NULL;
-		gtkaml_code_generator_set_root_class_definition (self, (_tmp0 = class_definition, (GTKAML_IS_ROOT_CLASS_DEFINITION (_tmp0) ? ((GtkamlRootClassDefinition*) _tmp0) : NULL)));
+		gtkaml_code_generator_set_root_class_definition (self, (_tmp0 = class_definition, (GTKAML_IS_ROOT_CLASS_DEFINITION (_tmp0) ? ((GtkamlRootClassDefinition*) (_tmp0)) : NULL)));
 		{
 			GeeSet* prefix_collection;
 			GeeIterator* prefix_it;
@@ -168,7 +168,7 @@ void gtkaml_code_generator_generate (GtkamlCodeGenerator* self, GtkamlClassDefin
 			prefix_it = gee_iterable_iterator (GEE_ITERABLE (prefix_collection));
 			while (gee_iterator_next (prefix_it)) {
 				char* prefix;
-				prefix = ((char*) gee_iterator_get (prefix_it));
+				prefix = ((char*) (gee_iterator_get (prefix_it)));
 				{
 					char* _tmp1;
 					_tmp1 = NULL;
@@ -177,8 +177,8 @@ void gtkaml_code_generator_generate (GtkamlCodeGenerator* self, GtkamlClassDefin
 					prefix = (g_free (prefix), NULL);
 				}
 			}
-			(prefix_collection == NULL ? NULL : (prefix_collection = (g_object_unref (prefix_collection), NULL)));
 			(prefix_it == NULL ? NULL : (prefix_it = (g_object_unref (prefix_it), NULL)));
+			(prefix_collection == NULL ? NULL : (prefix_collection = (g_object_unref (prefix_collection), NULL)));
 		}
 		gtkaml_code_generator_write_root_class_definition (self, self->priv->_root_class_definition);
 		gtkaml_code_generator_write_preconstruct (self, GTKAML_CLASS_DEFINITION (self->priv->_root_class_definition));
@@ -228,18 +228,16 @@ void gtkaml_code_generator_generate_children (GtkamlCodeGenerator* self, GtkamlC
 	g_return_if_fail (GTKAML_IS_CLASS_DEFINITION (class_definition));
 	{
 		GeeList* child_collection;
-		GeeIterator* child_it;
+		int child_it;
 		child_collection = gtkaml_class_definition_get_children (class_definition);
-		child_it = gee_iterable_iterator (GEE_ITERABLE (child_collection));
-		while (gee_iterator_next (child_it)) {
+		for (child_it = 0; child_it < gee_collection_get_size (GEE_COLLECTION (child_collection)); child_it = child_it + 1) {
 			GtkamlClassDefinition* child;
-			child = ((GtkamlClassDefinition*) gee_iterator_get (child_it));
+			child = ((GtkamlClassDefinition*) (gee_list_get (GEE_LIST (child_collection), child_it)));
 			{
 				gtkaml_code_generator_generate (self, child);
 				(child == NULL ? NULL : (child = (g_object_unref (child), NULL)));
 			}
 		}
-		(child_it == NULL ? NULL : (child_it = (g_object_unref (child_it), NULL)));
 	}
 }
 
@@ -294,7 +292,7 @@ void gtkaml_code_generator_write_construct_call (GtkamlCodeGenerator* self, cons
 			char* _tmp3;
 			_tmp4 = NULL;
 			_tmp3 = NULL;
-			real_construct_code = (_tmp4 = (_tmp3 = g_utf8_offset_to_pointer (real_construct_code, ((glong) 1)), g_strndup (_tmp3, g_utf8_offset_to_pointer (_tmp3, g_utf8_strlen (real_construct_code, -1) - 2) - _tmp3)), (real_construct_code = (g_free (real_construct_code), NULL)), _tmp4);
+			real_construct_code = (_tmp4 = (_tmp3 = g_utf8_offset_to_pointer (real_construct_code, ((glong) (1))), g_strndup (_tmp3, g_utf8_offset_to_pointer (_tmp3, g_utf8_strlen (real_construct_code, -1) - 2) - _tmp3)), (real_construct_code = (g_free (real_construct_code), NULL)), _tmp4);
 		} else {
 			char* _tmp5;
 			_tmp5 = NULL;
@@ -338,42 +336,38 @@ void gtkaml_code_generator_write_complex_attributes (GtkamlCodeGenerator* self,
 	g_return_if_fail (GTKAML_IS_CLASS_DEFINITION (class_definition));
 	{
 		GeeList* attr_collection;
-		GeeIterator* attr_it;
+		int attr_it;
 		attr_collection = gtkaml_class_definition_get_attrs (class_definition);
-		attr_it = gee_iterable_iterator (GEE_ITERABLE (attr_collection));
-		while (gee_iterator_next (attr_it)) {
+		for (attr_it = 0; attr_it < gee_collection_get_size (GEE_COLLECTION (attr_collection)); attr_it = attr_it + 1) {
 			GtkamlAttribute* attr;
-			attr = ((GtkamlAttribute*) gee_iterator_get (attr_it));
+			attr = ((GtkamlAttribute*) (gee_list_get (GEE_LIST (attr_collection), attr_it)));
 			{
 				if (GTKAML_IS_COMPLEX_ATTRIBUTE (attr)) {
 					GtkamlAttribute* _tmp0;
 					_tmp0 = NULL;
-					gtkaml_code_generator_generate (self, gtkaml_complex_attribute_get_complex_type (((_tmp0 = attr, (GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp0) ? ((GtkamlComplexAttribute*) _tmp0) : NULL)))));
+					gtkaml_code_generator_generate (self, gtkaml_complex_attribute_get_complex_type (((_tmp0 = attr, (GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp0) ? ((GtkamlComplexAttribute*) (_tmp0)) : NULL)))));
 				}
 				(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 			}
 		}
-		(attr_it == NULL ? NULL : (attr_it = (g_object_unref (attr_it), NULL)));
 	}
 	if (gtkaml_class_definition_get_construct_method (class_definition) != NULL && gtkaml_method_get_parameter_attributes (GTKAML_METHOD (gtkaml_class_definition_get_construct_method (class_definition))) != NULL) {
 		{
 			GeeList* attr_collection;
-			GeeIterator* attr_it;
+			int attr_it;
 			attr_collection = gtkaml_method_get_parameter_attributes (GTKAML_METHOD (gtkaml_class_definition_get_construct_method (class_definition)));
-			attr_it = gee_iterable_iterator (GEE_ITERABLE (attr_collection));
-			while (gee_iterator_next (attr_it)) {
+			for (attr_it = 0; attr_it < gee_collection_get_size (GEE_COLLECTION (attr_collection)); attr_it = attr_it + 1) {
 				GtkamlAttribute* attr;
-				attr = ((GtkamlAttribute*) gee_iterator_get (attr_it));
+				attr = ((GtkamlAttribute*) (gee_list_get (GEE_LIST (attr_collection), attr_it)));
 				{
 					if (GTKAML_IS_COMPLEX_ATTRIBUTE (attr)) {
 						GtkamlAttribute* _tmp1;
 						_tmp1 = NULL;
-						gtkaml_code_generator_generate (self, gtkaml_complex_attribute_get_complex_type (((_tmp1 = attr, (GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp1) ? ((GtkamlComplexAttribute*) _tmp1) : NULL)))));
+						gtkaml_code_generator_generate (self, gtkaml_complex_attribute_get_complex_type (((_tmp1 = attr, (GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp1) ? ((GtkamlComplexAttribute*) (_tmp1)) : NULL)))));
 					}
 					(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 				}
 			}
-			(attr_it == NULL ? NULL : (attr_it = (g_object_unref (attr_it), NULL)));
 		}
 	}
 	first = TRUE;
@@ -381,23 +375,21 @@ void gtkaml_code_generator_write_complex_attributes (GtkamlCodeGenerator* self,
 	if (gtkaml_class_definition_get_add_method (class_definition) != NULL && gtkaml_method_get_parameter_attributes (GTKAML_METHOD (gtkaml_class_definition_get_add_method (class_definition))) != NULL) {
 		{
 			GeeList* attr_collection;
-			GeeIterator* attr_it;
+			int attr_it;
 			attr_collection = gtkaml_method_get_parameter_attributes (GTKAML_METHOD (gtkaml_class_definition_get_add_method (class_definition)));
-			attr_it = gee_iterable_iterator (GEE_ITERABLE (attr_collection));
-			while (gee_iterator_next (attr_it)) {
+			for (attr_it = 0; attr_it < gee_collection_get_size (GEE_COLLECTION (attr_collection)); attr_it = attr_it + 1) {
 				GtkamlAttribute* attr;
-				attr = ((GtkamlAttribute*) gee_iterator_get (attr_it));
+				attr = ((GtkamlAttribute*) (gee_list_get (GEE_LIST (attr_collection), attr_it)));
 				{
 					if (GTKAML_IS_COMPLEX_ATTRIBUTE (attr) && !first) {
 						GtkamlAttribute* _tmp2;
 						_tmp2 = NULL;
-						gtkaml_code_generator_generate (self, gtkaml_complex_attribute_get_complex_type (((_tmp2 = attr, (GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp2) ? ((GtkamlComplexAttribute*) _tmp2) : NULL)))));
+						gtkaml_code_generator_generate (self, gtkaml_complex_attribute_get_complex_type (((_tmp2 = attr, (GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp2) ? ((GtkamlComplexAttribute*) (_tmp2)) : NULL)))));
 					}
 					first = FALSE;
 					(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 				}
 			}
-			(attr_it == NULL ? NULL : (attr_it = (g_object_unref (attr_it), NULL)));
 		}
 	}
 }
@@ -466,18 +458,16 @@ void gtkaml_code_generator_write_root_class_definition (GtkamlCodeGenerator* sel
 	self->priv->class_end = (_tmp15 = g_strconcat (self->priv->class_end, ("}\n"), NULL), (self->priv->class_end = (g_free (self->priv->class_end), NULL)), _tmp15);
 	{
 		GeeList* code_collection;
-		GeeIterator* code_it;
+		int code_it;
 		code_collection = gtkaml_root_class_definition_get_code (root_class_definition);
-		code_it = gee_iterable_iterator (GEE_ITERABLE (code_collection));
-		while (gee_iterator_next (code_it)) {
+		for (code_it = 0; code_it < gee_collection_get_size (GEE_COLLECTION (code_collection)); code_it = code_it + 1) {
 			char* code;
-			code = ((char*) gee_iterator_get (code_it));
+			code = ((char*) (gee_list_get (GEE_LIST (code_collection), code_it)));
 			{
 				gtkaml_code_generator_add_code (self, code);
 				code = (g_free (code), NULL);
 			}
 		}
-		(code_it == NULL ? NULL : (code_it = (g_object_unref (code_it), NULL)));
 	}
 	ns = (g_free (ns), NULL);
 	name = (g_free (name), NULL);
@@ -554,18 +544,16 @@ void gtkaml_code_generator_write_root_constructor_parameters (GtkamlCodeGenerato
 	g_return_if_fail (GTKAML_IS_ROOT_CLASS_DEFINITION (class_definition));
 	{
 		GeeList* attr_collection;
-		GeeIterator* attr_it;
+		int attr_it;
 		attr_collection = gtkaml_method_get_parameter_attributes (GTKAML_METHOD (gtkaml_class_definition_get_construct_method (GTKAML_CLASS_DEFINITION (class_definition))));
-		attr_it = gee_iterable_iterator (GEE_ITERABLE (attr_collection));
-		while (gee_iterator_next (attr_it)) {
+		for (attr_it = 0; attr_it < gee_collection_get_size (GEE_COLLECTION (attr_collection)); attr_it = attr_it + 1) {
 			GtkamlAttribute* attr;
-			attr = ((GtkamlAttribute*) gee_iterator_get (attr_it));
+			attr = ((GtkamlAttribute*) (gee_list_get (GEE_LIST (attr_collection), attr_it)));
 			{
 				gtkaml_code_generator_write_setter (self, GTKAML_CLASS_DEFINITION (class_definition), attr);
 				(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 			}
 		}
-		(attr_it == NULL ? NULL : (attr_it = (g_object_unref (attr_it), NULL)));
 	}
 }
 
@@ -608,7 +596,7 @@ void gtkaml_code_generator_write_constructor (GtkamlCodeGenerator* self, GtkamlC
 		char* _tmp11;
 		char* _tmp10;
 		char* _tmp9;
-		attr = ((GtkamlAttribute*) gee_list_get (gtkaml_method_get_parameter_attributes (GTKAML_METHOD (gtkaml_class_definition_get_construct_method (class_definition))), i));
+		attr = ((GtkamlAttribute*) (gee_list_get (gtkaml_method_get_parameter_attributes (GTKAML_METHOD (gtkaml_class_definition_get_construct_method (class_definition))), i)));
 		_tmp11 = NULL;
 		_tmp10 = NULL;
 		_tmp9 = NULL;
@@ -624,7 +612,7 @@ void gtkaml_code_generator_write_constructor (GtkamlCodeGenerator* self, GtkamlC
 		_tmp14 = NULL;
 		_tmp13 = NULL;
 		_tmp12 = NULL;
-		self->priv->constructors = (_tmp14 = g_strconcat (self->priv->constructors, (_tmp13 = (gtkaml_code_generator_generate_literal (self, (_tmp12 = ((GtkamlAttribute*) gee_list_get (gtkaml_method_get_parameter_attributes (GTKAML_METHOD (gtkaml_class_definition_get_construct_method (class_definition))), i)))))), NULL), (self->priv->constructors = (g_free (self->priv->constructors), NULL)), _tmp14);
+		self->priv->constructors = (_tmp14 = g_strconcat (self->priv->constructors, (_tmp13 = (gtkaml_code_generator_generate_literal (self, (_tmp12 = ((GtkamlAttribute*) (gee_list_get (gtkaml_method_get_parameter_attributes (GTKAML_METHOD (gtkaml_class_definition_get_construct_method (class_definition))), i))))))), NULL), (self->priv->constructors = (g_free (self->priv->constructors), NULL)), _tmp14);
 		_tmp13 = (g_free (_tmp13), NULL);
 		(_tmp12 == NULL ? NULL : (_tmp12 = (g_object_unref (_tmp12), NULL)));
 	}
@@ -654,7 +642,7 @@ void gtkaml_code_generator_write_add (GtkamlCodeGenerator* self, GtkamlClassDefi
 		char* _tmp4;
 		char* _tmp3;
 		char* _tmp2;
-		attr = ((GtkamlAttribute*) gee_list_get (gtkaml_method_get_parameter_attributes (GTKAML_METHOD (gtkaml_class_definition_get_add_method (child_definition))), i));
+		attr = ((GtkamlAttribute*) (gee_list_get (gtkaml_method_get_parameter_attributes (GTKAML_METHOD (gtkaml_class_definition_get_add_method (child_definition))), i)));
 		_tmp4 = NULL;
 		_tmp3 = NULL;
 		_tmp2 = NULL;
@@ -670,7 +658,7 @@ void gtkaml_code_generator_write_add (GtkamlCodeGenerator* self, GtkamlClassDefi
 		_tmp7 = NULL;
 		_tmp6 = NULL;
 		_tmp5 = NULL;
-		self->priv->construct_body = (_tmp7 = g_strconcat (self->priv->construct_body, (_tmp6 = (gtkaml_code_generator_generate_literal (self, (_tmp5 = ((GtkamlAttribute*) gee_list_get (gtkaml_method_get_parameter_attributes (GTKAML_METHOD (gtkaml_class_definition_get_add_method (child_definition))), i)))))), NULL), (self->priv->construct_body = (g_free (self->priv->construct_body), NULL)), _tmp7);
+		self->priv->construct_body = (_tmp7 = g_strconcat (self->priv->construct_body, (_tmp6 = (gtkaml_code_generator_generate_literal (self, (_tmp5 = ((GtkamlAttribute*) (gee_list_get (gtkaml_method_get_parameter_attributes (GTKAML_METHOD (gtkaml_class_definition_get_add_method (child_definition))), i))))))), NULL), (self->priv->construct_body = (g_free (self->priv->construct_body), NULL)), _tmp7);
 		_tmp6 = (g_free (_tmp6), NULL);
 		(_tmp5 == NULL ? NULL : (_tmp5 = (g_object_unref (_tmp5), NULL)));
 	}
@@ -684,12 +672,11 @@ void gtkaml_code_generator_write_setters (GtkamlCodeGenerator* self, GtkamlClass
 	g_return_if_fail (GTKAML_IS_CLASS_DEFINITION (class_definition));
 	{
 		GeeList* attr_collection;
-		GeeIterator* attr_it;
+		int attr_it;
 		attr_collection = gtkaml_class_definition_get_attrs (class_definition);
-		attr_it = gee_iterable_iterator (GEE_ITERABLE (attr_collection));
-		while (gee_iterator_next (attr_it)) {
+		for (attr_it = 0; attr_it < gee_collection_get_size (GEE_COLLECTION (attr_collection)); attr_it = attr_it + 1) {
 			GtkamlAttribute* attr;
-			attr = ((GtkamlAttribute*) gee_iterator_get (attr_it));
+			attr = ((GtkamlAttribute*) (gee_list_get (GEE_LIST (attr_collection), attr_it)));
 			{
 				if (VALA_IS_FIELD (gtkaml_attribute_get_target_type (attr))) {
 					gtkaml_code_generator_write_setter (self, class_definition, attr);
@@ -705,7 +692,6 @@ void gtkaml_code_generator_write_setters (GtkamlCodeGenerator* self, GtkamlClass
 							vala_report_error (gtkaml_class_definition_get_source_reference (class_definition), (_tmp0 = g_strdup_printf ("Unknown attribute type %s", gtkaml_attribute_get_name (attr))));
 							_tmp0 = (g_free (_tmp0), NULL);
 							(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
-							(attr_it == NULL ? NULL : (attr_it = (g_object_unref (attr_it), NULL)));
 							return;
 						}
 					}
@@ -713,7 +699,6 @@ void gtkaml_code_generator_write_setters (GtkamlCodeGenerator* self, GtkamlClass
 				(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 			}
 		}
-		(attr_it == NULL ? NULL : (attr_it = (g_object_unref (attr_it), NULL)));
 	}
 }
 
@@ -721,7 +706,7 @@ void gtkaml_code_generator_write_setters (GtkamlCodeGenerator* self, GtkamlClass
 char* gtkaml_code_generator_prefix_to_namespace (GtkamlCodeGenerator* self, const char* prefix) {
 	g_return_val_if_fail (GTKAML_IS_CODE_GENERATOR (self), NULL);
 	g_return_val_if_fail (prefix != NULL, NULL);
-	return ((char*) gee_map_get (gtkaml_root_class_definition_get_prefixes_namespaces (self->priv->_root_class_definition), ((prefix == NULL) ? "" : prefix)));
+	return ((char*) (gee_map_get (gtkaml_root_class_definition_get_prefixes_namespaces (self->priv->_root_class_definition), ((prefix == NULL) ? "" : prefix))));
 }
 
 
@@ -745,6 +730,7 @@ char* gtkaml_code_generator_generate_literal (GtkamlCodeGenerator* self, GtkamlA
 	char* value;
 	const char* _tmp15;
 	char* stripped_value;
+	char* _tmp31;
 	g_return_val_if_fail (GTKAML_IS_CODE_GENERATOR (self), NULL);
 	g_return_val_if_fail (GTKAML_IS_ATTRIBUTE (attr), NULL);
 	literal = NULL;
@@ -756,11 +742,11 @@ char* gtkaml_code_generator_generate_literal (GtkamlCodeGenerator* self, GtkamlA
 		_tmp1 = NULL;
 		_tmp0 = NULL;
 		_tmp2 = NULL;
-		return (_tmp2 = (_tmp1 = gtkaml_class_definition_get_identifier (gtkaml_complex_attribute_get_complex_type (((_tmp0 = attr, (GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp0) ? ((GtkamlComplexAttribute*) _tmp0) : NULL))))), (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (literal = (g_free (literal), NULL)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp2);
+		return (_tmp2 = (_tmp1 = gtkaml_class_definition_get_identifier (gtkaml_complex_attribute_get_complex_type (((_tmp0 = attr, (GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp0) ? ((GtkamlComplexAttribute*) (_tmp0)) : NULL))))), (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (literal = (g_free (literal), NULL)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp2);
 	}
 	_tmp4 = NULL;
 	_tmp3 = NULL;
-	value = (_tmp4 = gtkaml_simple_attribute_get_value (((_tmp3 = attr, (GTKAML_IS_SIMPLE_ATTRIBUTE (_tmp3) ? ((GtkamlSimpleAttribute*) _tmp3) : NULL)))), (_tmp4 == NULL ? NULL : g_strdup (_tmp4)));
+	value = (_tmp4 = gtkaml_simple_attribute_get_value (((_tmp3 = attr, (GTKAML_IS_SIMPLE_ATTRIBUTE (_tmp3) ? ((GtkamlSimpleAttribute*) (_tmp3)) : NULL)))), (_tmp4 == NULL ? NULL : g_strdup (_tmp4)));
 	if (VALA_IS_FIELD (gtkaml_attribute_get_target_type (attr))) {
 		ValaDataType* _tmp7;
 		ValaDataType* _tmp6;
@@ -768,7 +754,7 @@ char* gtkaml_code_generator_generate_literal (GtkamlCodeGenerator* self, GtkamlA
 		_tmp7 = NULL;
 		_tmp6 = NULL;
 		_tmp5 = NULL;
-		type = (_tmp7 = (_tmp6 = vala_field_get_type_reference (((_tmp5 = gtkaml_attribute_get_target_type (attr), (VALA_IS_FIELD (_tmp5) ? ((ValaField*) _tmp5) : NULL)))), (_tmp6 == NULL ? NULL : g_object_ref (_tmp6))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp7);
+		type = (_tmp7 = (_tmp6 = vala_field_get_field_type (((_tmp5 = gtkaml_attribute_get_target_type (attr), (VALA_IS_FIELD (_tmp5) ? ((ValaField*) (_tmp5)) : NULL)))), (_tmp6 == NULL ? NULL : g_object_ref (_tmp6))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp7);
 	} else {
 		if (VALA_IS_PROPERTY (gtkaml_attribute_get_target_type (attr))) {
 			ValaDataType* _tmp10;
@@ -777,7 +763,7 @@ char* gtkaml_code_generator_generate_literal (GtkamlCodeGenerator* self, GtkamlA
 			_tmp10 = NULL;
 			_tmp9 = NULL;
 			_tmp8 = NULL;
-			type = (_tmp10 = (_tmp9 = vala_property_get_type_reference (((_tmp8 = gtkaml_attribute_get_target_type (attr), (VALA_IS_PROPERTY (_tmp8) ? ((ValaProperty*) _tmp8) : NULL)))), (_tmp9 == NULL ? NULL : g_object_ref (_tmp9))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp10);
+			type = (_tmp10 = (_tmp9 = vala_property_get_property_type (((_tmp8 = gtkaml_attribute_get_target_type (attr), (VALA_IS_PROPERTY (_tmp8) ? ((ValaProperty*) (_tmp8)) : NULL)))), (_tmp9 == NULL ? NULL : g_object_ref (_tmp9))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp10);
 		} else {
 			if (VALA_IS_FORMAL_PARAMETER (gtkaml_attribute_get_target_type (attr))) {
 				ValaDataType* _tmp13;
@@ -786,7 +772,7 @@ char* gtkaml_code_generator_generate_literal (GtkamlCodeGenerator* self, GtkamlA
 				_tmp13 = NULL;
 				_tmp12 = NULL;
 				_tmp11 = NULL;
-				type = (_tmp13 = (_tmp12 = vala_formal_parameter_get_type_reference (((_tmp11 = gtkaml_attribute_get_target_type (attr), (VALA_IS_FORMAL_PARAMETER (_tmp11) ? ((ValaFormalParameter*) _tmp11) : NULL)))), (_tmp12 == NULL ? NULL : g_object_ref (_tmp12))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp13);
+				type = (_tmp13 = (_tmp12 = vala_formal_parameter_get_parameter_type (((_tmp11 = gtkaml_attribute_get_target_type (attr), (VALA_IS_FORMAL_PARAMETER (_tmp11) ? ((ValaFormalParameter*) (_tmp11)) : NULL)))), (_tmp12 == NULL ? NULL : g_object_ref (_tmp12))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), _tmp13);
 			} else {
 				char* _tmp14;
 				_tmp14 = NULL;
@@ -798,28 +784,27 @@ char* gtkaml_code_generator_generate_literal (GtkamlCodeGenerator* self, GtkamlA
 	_tmp15 = NULL;
 	stripped_value = (_tmp15 = value, (_tmp15 == NULL ? NULL : g_strdup (_tmp15)));
 	g_strstrip (stripped_value);
-	if (VALA_IS_UNRESOLVED_TYPE (type)) {
-		ValaUnresolvedType* _tmp17;
-		ValaDataType* _tmp16;
-		ValaUnresolvedType* utype;
-		char* _tmp29;
-		_tmp17 = NULL;
-		_tmp16 = NULL;
-		utype = (_tmp17 = (_tmp16 = type, (VALA_IS_UNRESOLVED_TYPE (_tmp16) ? ((ValaUnresolvedType*) _tmp16) : NULL)), (_tmp17 == NULL ? NULL : g_object_ref (_tmp17)));
-		if (g_str_has_prefix (stripped_value, "{")) {
-			if (g_str_has_suffix (stripped_value, "}")) {
-				char* _tmp19;
-				char* _tmp18;
-				_tmp19 = NULL;
-				_tmp18 = NULL;
-				literal = (_tmp19 = (_tmp18 = g_utf8_offset_to_pointer (stripped_value, ((glong) 1)), g_strndup (_tmp18, g_utf8_offset_to_pointer (_tmp18, g_utf8_strlen (stripped_value, -1) - 2) - _tmp18)), (literal = (g_free (literal), NULL)), _tmp19);
-			} else {
-				char* _tmp20;
-				_tmp20 = NULL;
-				vala_report_error (NULL, (_tmp20 = g_strdup_printf ("Attribute %s not properly ended", gtkaml_attribute_get_name (attr))));
-				_tmp20 = (g_free (_tmp20), NULL);
-			}
+	if (g_str_has_prefix (stripped_value, "{")) {
+		if (g_str_has_suffix (stripped_value, "}")) {
+			char* _tmp17;
+			char* _tmp16;
+			_tmp17 = NULL;
+			_tmp16 = NULL;
+			literal = (_tmp17 = (_tmp16 = g_utf8_offset_to_pointer (stripped_value, ((glong) (1))), g_strndup (_tmp16, g_utf8_offset_to_pointer (_tmp16, g_utf8_strlen (stripped_value, -1) - 2) - _tmp16)), (literal = (g_free (literal), NULL)), _tmp17);
 		} else {
+			char* _tmp18;
+			_tmp18 = NULL;
+			vala_report_error (NULL, (_tmp18 = g_strdup_printf ("Attribute %s not properly ended", gtkaml_attribute_get_name (attr))));
+			_tmp18 = (g_free (_tmp18), NULL);
+		}
+	} else {
+		if (VALA_IS_UNRESOLVED_TYPE (type)) {
+			ValaUnresolvedType* _tmp20;
+			ValaDataType* _tmp19;
+			ValaUnresolvedType* utype;
+			_tmp20 = NULL;
+			_tmp19 = NULL;
+			utype = (_tmp20 = (_tmp19 = type, (VALA_IS_UNRESOLVED_TYPE (_tmp19) ? ((ValaUnresolvedType*) (_tmp19)) : NULL)), (_tmp20 == NULL ? NULL : g_object_ref (_tmp20)));
 			if (_vala_strcmp0 (vala_unresolved_symbol_get_name (vala_unresolved_type_get_unresolved_symbol (utype)), "string") == 0) {
 				char* _tmp23;
 				char* _tmp22;
@@ -851,22 +836,19 @@ char* gtkaml_code_generator_generate_literal (GtkamlCodeGenerator* self, GtkamlA
 					literal = (_tmp28 = (_tmp27 = stripped_value, (_tmp27 == NULL ? NULL : g_strdup (_tmp27))), (literal = (g_free (literal), NULL)), _tmp28);
 				}
 			}
+			(utype == NULL ? NULL : (utype = (g_object_unref (utype), NULL)));
+		} else {
+			char* _tmp29;
+			char* _tmp30;
+			_tmp29 = NULL;
+			vala_report_error (NULL, (_tmp29 = g_strdup_printf ("Don't know any literal of type '%s'\n", vala_symbol_get_name (gtkaml_attribute_get_target_type (attr)))));
+			_tmp29 = (g_free (_tmp29), NULL);
+			_tmp30 = NULL;
+			return (_tmp30 = stripped_value, (literal = (g_free (literal), NULL)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (value = (g_free (value), NULL)), _tmp30);
 		}
-		_tmp29 = NULL;
-		return (_tmp29 = literal, (utype == NULL ? NULL : (utype = (g_object_unref (utype), NULL))), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (value = (g_free (value), NULL)), (stripped_value = (g_free (stripped_value), NULL)), _tmp29);
-	} else {
-		char* _tmp30;
-		char* _tmp31;
-		_tmp30 = NULL;
-		vala_report_error (NULL, (_tmp30 = g_strdup_printf ("Don't know any literal of type %s\n", vala_symbol_get_name (gtkaml_attribute_get_target_type (attr)))));
-		_tmp30 = (g_free (_tmp30), NULL);
-		_tmp31 = NULL;
-		return (_tmp31 = stripped_value, (literal = (g_free (literal), NULL)), (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (value = (g_free (value), NULL)), _tmp31);
 	}
-	literal = (g_free (literal), NULL);
-	(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
-	value = (g_free (value), NULL);
-	stripped_value = (g_free (stripped_value), NULL);
+	_tmp31 = NULL;
+	return (_tmp31 = literal, (type == NULL ? NULL : (type = (g_object_unref (type), NULL))), (value = (g_free (value), NULL)), (stripped_value = (g_free (stripped_value), NULL)), _tmp31);
 }
 
 
@@ -914,10 +896,10 @@ void gtkaml_code_generator_write_signal_setter (GtkamlCodeGenerator* self, Gtkam
 	}
 	_tmp2 = NULL;
 	_tmp1 = NULL;
-	simple_attribute = (_tmp2 = (_tmp1 = signal_attr, (GTKAML_IS_SIMPLE_ATTRIBUTE (_tmp1) ? ((GtkamlSimpleAttribute*) _tmp1) : NULL)), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)));
+	simple_attribute = (_tmp2 = (_tmp1 = signal_attr, (GTKAML_IS_SIMPLE_ATTRIBUTE (_tmp1) ? ((GtkamlSimpleAttribute*) (_tmp1)) : NULL)), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)));
 	_tmp4 = NULL;
 	_tmp3 = NULL;
-	the_signal = (_tmp4 = (_tmp3 = gtkaml_attribute_get_target_type (GTKAML_ATTRIBUTE (simple_attribute)), (VALA_IS_SIGNAL (_tmp3) ? ((ValaSignal*) _tmp3) : NULL)), (_tmp4 == NULL ? NULL : g_object_ref (_tmp4)));
+	the_signal = (_tmp4 = (_tmp3 = gtkaml_attribute_get_target_type (GTKAML_ATTRIBUTE (simple_attribute)), (VALA_IS_SIGNAL (_tmp3) ? ((ValaSignal*) (_tmp3)) : NULL)), (_tmp4 == NULL ? NULL : g_object_ref (_tmp4)));
 	parameters_joined = g_strdup ("");
 	_tmp5 = NULL;
 	body = (_tmp5 = gtkaml_simple_attribute_get_value (simple_attribute), (_tmp5 == NULL ? NULL : g_strdup (_tmp5)));
@@ -930,7 +912,7 @@ void gtkaml_code_generator_write_signal_setter (GtkamlCodeGenerator* self, Gtkam
 			char* _tmp8;
 			_tmp7 = NULL;
 			_tmp6 = NULL;
-			parameters_joined = (_tmp7 = (_tmp6 = g_utf8_offset_to_pointer (body, ((glong) 1)), g_strndup (_tmp6, g_utf8_offset_to_pointer (_tmp6, g_utf8_strlen (body, -1) - 2) - _tmp6)), (parameters_joined = (g_free (parameters_joined), NULL)), _tmp7);
+			parameters_joined = (_tmp7 = (_tmp6 = g_utf8_offset_to_pointer (body, ((glong) (1))), g_strndup (_tmp6, g_utf8_offset_to_pointer (_tmp6, g_utf8_strlen (body, -1) - 2) - _tmp6)), (parameters_joined = (g_free (parameters_joined), NULL)), _tmp7);
 			_tmp9 = NULL;
 			_tmp8 = NULL;
 			self->priv->construct_body = (_tmp9 = g_strconcat (self->priv->construct_body, (_tmp8 = (g_strdup_printf ("\t\t%s.%s += %s;\n", gtkaml_class_definition_get_identifier (class_definition), gtkaml_attribute_get_name (signal_attr), parameters_joined))), NULL), (self->priv->construct_body = (g_free (self->priv->construct_body), NULL)), _tmp9);
@@ -973,12 +955,11 @@ void gtkaml_code_generator_write_signal_setter (GtkamlCodeGenerator* self, Gtkam
 		parameter_names_length1 = _tmp13;
 		{
 			GeeList* p_collection;
-			GeeIterator* p_it;
+			int p_it;
 			p_collection = parameters;
-			p_it = gee_iterable_iterator (GEE_ITERABLE (p_collection));
-			while (gee_iterator_next (p_it)) {
+			for (p_it = 0; p_it < gee_collection_get_size (GEE_COLLECTION (p_collection)); p_it = p_it + 1) {
 				ValaFormalParameter* p;
-				p = ((ValaFormalParameter*) gee_iterator_get (p_it));
+				p = ((ValaFormalParameter*) (gee_list_get (GEE_LIST (p_collection), p_it)));
 				{
 					gint _tmp16;
 					char* _tmp15;
@@ -990,7 +971,6 @@ void gtkaml_code_generator_write_signal_setter (GtkamlCodeGenerator* self, Gtkam
 					(p == NULL ? NULL : (p = (g_object_unref (p), NULL)));
 				}
 			}
-			(p_it == NULL ? NULL : (p_it = (g_object_unref (p_it), NULL)));
 		}
 		_tmp17 = NULL;
 		_tmp18 = gee_collection_get_size (GEE_COLLECTION (parameters));
@@ -1018,7 +998,7 @@ void gtkaml_code_generator_write_signal_setter (GtkamlCodeGenerator* self, Gtkam
 	parameters_joined = (g_free (parameters_joined), NULL);
 	body = (g_free (body), NULL);
 	(parameters == NULL ? NULL : (parameters = (g_object_unref (parameters), NULL)));
-	parameter_names = (_vala_array_free (parameter_names, parameter_names_length1, ((GDestroyNotify) g_free)), NULL);
+	parameter_names = (_vala_array_free (parameter_names, parameter_names_length1, ((GDestroyNotify) (g_free))), NULL);
 }
 
 
@@ -1097,7 +1077,7 @@ static void gtkaml_code_generator_class_init (GtkamlCodeGeneratorClass * klass)
 }
 
 
-static void gtkaml_code_generator_init (GtkamlCodeGenerator * self) {
+static void gtkaml_code_generator_instance_init (GtkamlCodeGenerator * self) {
 	self->priv = GTKAML_CODE_GENERATOR_GET_PRIVATE (self);
 	self->priv->using_directives = g_new0 (char, 1);
 	self->priv->class_start = g_new0 (char, 1);
@@ -1132,7 +1112,7 @@ static void gtkaml_code_generator_dispose (GObject * obj) {
 GType gtkaml_code_generator_get_type (void) {
 	static GType gtkaml_code_generator_type_id = 0;
 	if (G_UNLIKELY (gtkaml_code_generator_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GtkamlCodeGeneratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_code_generator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlCodeGenerator), 0, (GInstanceInitFunc) gtkaml_code_generator_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GtkamlCodeGeneratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_code_generator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlCodeGenerator), 0, (GInstanceInitFunc) gtkaml_code_generator_instance_init };
 		gtkaml_code_generator_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlCodeGenerator", &g_define_type_info, 0);
 	}
 	return gtkaml_code_generator_type_id;
@@ -1144,12 +1124,12 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 		int i;
 		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) array)[i] != NULL)
-			destroy_func (((gpointer*) array)[i]);
+			if (((gpointer*) (array))[i] != NULL)
+			destroy_func (((gpointer*) (array))[i]);
 		}
 		else
-		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) array)[i]);
+		for (i = 0; ((gpointer*) (array))[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) (array))[i]);
 		}
 	}
 	g_free (array);
