@@ -30,6 +30,7 @@
 #include <vala/valadatatype.h>
 #include <vala/valaunresolvedtype.h>
 #include <vala/valaunresolvedsymbol.h>
+#include <vala/valaobjecttypesymbol.h>
 #include <vala/valamember.h>
 #include <vala/valascope.h>
 #include <vala/valanamespace.h>
@@ -114,18 +115,16 @@ void gtkaml_implicits_resolver_resolve (GtkamlImplicitsResolver* self, GtkamlCla
 	gtkaml_implicits_resolver_determine_attribute_types (self, class_definition);
 	{
 		GeeList* child_collection;
-		GeeIterator* child_it;
+		int child_it;
 		child_collection = gtkaml_class_definition_get_children (class_definition);
-		child_it = gee_iterable_iterator (GEE_ITERABLE (child_collection));
-		while (gee_iterator_next (child_it)) {
+		for (child_it = 0; child_it < gee_collection_get_size (GEE_COLLECTION (child_collection)); child_it = child_it + 1) {
 			GtkamlClassDefinition* child;
-			child = ((GtkamlClassDefinition*) gee_iterator_get (child_it));
+			child = ((GtkamlClassDefinition*) (gee_list_get (GEE_LIST (child_collection), child_it)));
 			{
 				gtkaml_implicits_resolver_resolve (self, child);
 				(child == NULL ? NULL : (child = (g_object_unref (child), NULL)));
 			}
 		}
-		(child_it == NULL ? NULL : (child_it = (g_object_unref (child_it), NULL)));
 	}
 }
 
@@ -136,42 +135,38 @@ void gtkaml_implicits_resolver_resolve_complex_attributes (GtkamlImplicitsResolv
 	g_return_if_fail (GTKAML_IS_CLASS_DEFINITION (class_definition));
 	{
 		GeeList* attr_collection;
-		GeeIterator* attr_it;
+		int attr_it;
 		attr_collection = gtkaml_class_definition_get_attrs (class_definition);
-		attr_it = gee_iterable_iterator (GEE_ITERABLE (attr_collection));
-		while (gee_iterator_next (attr_it)) {
+		for (attr_it = 0; attr_it < gee_collection_get_size (GEE_COLLECTION (attr_collection)); attr_it = attr_it + 1) {
 			GtkamlAttribute* attr;
-			attr = ((GtkamlAttribute*) gee_iterator_get (attr_it));
+			attr = ((GtkamlAttribute*) (gee_list_get (GEE_LIST (attr_collection), attr_it)));
 			{
 				if (GTKAML_IS_COMPLEX_ATTRIBUTE (attr)) {
 					GtkamlAttribute* _tmp0;
 					_tmp0 = NULL;
-					gtkaml_implicits_resolver_resolve (self, gtkaml_complex_attribute_get_complex_type (((_tmp0 = attr, (GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp0) ? ((GtkamlComplexAttribute*) _tmp0) : NULL)))));
+					gtkaml_implicits_resolver_resolve (self, gtkaml_complex_attribute_get_complex_type (((_tmp0 = attr, (GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp0) ? ((GtkamlComplexAttribute*) (_tmp0)) : NULL)))));
 				}
 				(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 			}
 		}
-		(attr_it == NULL ? NULL : (attr_it = (g_object_unref (attr_it), NULL)));
 	}
 	if (gtkaml_class_definition_get_construct_method (class_definition) != NULL && gtkaml_method_get_parameter_attributes (GTKAML_METHOD (gtkaml_class_definition_get_construct_method (class_definition))) != NULL) {
 		{
 			GeeList* attr_collection;
-			GeeIterator* attr_it;
+			int attr_it;
 			attr_collection = gtkaml_method_get_parameter_attributes (GTKAML_METHOD (gtkaml_class_definition_get_construct_method (class_definition)));
-			attr_it = gee_iterable_iterator (GEE_ITERABLE (attr_collection));
-			while (gee_iterator_next (attr_it)) {
+			for (attr_it = 0; attr_it < gee_collection_get_size (GEE_COLLECTION (attr_collection)); attr_it = attr_it + 1) {
 				GtkamlAttribute* attr;
-				attr = ((GtkamlAttribute*) gee_iterator_get (attr_it));
+				attr = ((GtkamlAttribute*) (gee_list_get (GEE_LIST (attr_collection), attr_it)));
 				{
 					if (GTKAML_IS_COMPLEX_ATTRIBUTE (attr)) {
 						GtkamlAttribute* _tmp1;
 						_tmp1 = NULL;
-						gtkaml_implicits_resolver_resolve (self, gtkaml_complex_attribute_get_complex_type (((_tmp1 = attr, (GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp1) ? ((GtkamlComplexAttribute*) _tmp1) : NULL)))));
+						gtkaml_implicits_resolver_resolve (self, gtkaml_complex_attribute_get_complex_type (((_tmp1 = attr, (GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp1) ? ((GtkamlComplexAttribute*) (_tmp1)) : NULL)))));
 					}
 					(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 				}
 			}
-			(attr_it == NULL ? NULL : (attr_it = (g_object_unref (attr_it), NULL)));
 		}
 	}
 	first = TRUE;
@@ -179,23 +174,21 @@ void gtkaml_implicits_resolver_resolve_complex_attributes (GtkamlImplicitsResolv
 	if (gtkaml_class_definition_get_add_method (class_definition) != NULL && gtkaml_method_get_parameter_attributes (GTKAML_METHOD (gtkaml_class_definition_get_add_method (class_definition))) != NULL) {
 		{
 			GeeList* attr_collection;
-			GeeIterator* attr_it;
+			int attr_it;
 			attr_collection = gtkaml_method_get_parameter_attributes (GTKAML_METHOD (gtkaml_class_definition_get_add_method (class_definition)));
-			attr_it = gee_iterable_iterator (GEE_ITERABLE (attr_collection));
-			while (gee_iterator_next (attr_it)) {
+			for (attr_it = 0; attr_it < gee_collection_get_size (GEE_COLLECTION (attr_collection)); attr_it = attr_it + 1) {
 				GtkamlAttribute* attr;
-				attr = ((GtkamlAttribute*) gee_iterator_get (attr_it));
+				attr = ((GtkamlAttribute*) (gee_list_get (GEE_LIST (attr_collection), attr_it)));
 				{
 					if (GTKAML_IS_COMPLEX_ATTRIBUTE (attr) && !first) {
 						GtkamlAttribute* _tmp2;
 						_tmp2 = NULL;
-						gtkaml_implicits_resolver_resolve (self, gtkaml_complex_attribute_get_complex_type (((_tmp2 = attr, (GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp2) ? ((GtkamlComplexAttribute*) _tmp2) : NULL)))));
+						gtkaml_implicits_resolver_resolve (self, gtkaml_complex_attribute_get_complex_type (((_tmp2 = attr, (GTKAML_IS_COMPLEX_ATTRIBUTE (_tmp2) ? ((GtkamlComplexAttribute*) (_tmp2)) : NULL)))));
 					}
 					first = FALSE;
 					(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 				}
 			}
-			(attr_it == NULL ? NULL : (attr_it = (g_object_unref (attr_it), NULL)));
 		}
 	}
 }
@@ -213,33 +206,31 @@ static void gtkaml_implicits_resolver_determine_add_method (GtkamlImplicitsResol
 	GtkamlMethodMatcher* method_matcher;
 	g_return_if_fail (GTKAML_IS_IMPLICITS_RESOLVER (self));
 	g_return_if_fail (GTKAML_IS_CLASS_DEFINITION (child_definition));
-	adds = GEE_LIST (gee_array_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	adds = GEE_LIST (gee_array_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 	gtkaml_implicits_resolver_lookup_container_add_methods (self, gtkaml_class_definition_get_base_ns (gtkaml_class_definition_get_parent_container (child_definition)), gtkaml_class_definition_get_base_type (gtkaml_class_definition_get_parent_container (child_definition)), adds);
 	determined_add = NULL;
 	new_method = gtkaml_add_method_new ();
-	to_remove = GEE_LIST (gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	to_remove = GEE_LIST (gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 	/*pass one: see if we find an explicitly specified add method*/
 	{
 		GeeList* add_collection;
-		GeeIterator* add_it;
+		int add_it;
 		add_collection = adds;
-		add_it = gee_iterable_iterator (GEE_ITERABLE (add_collection));
-		while (gee_iterator_next (add_it)) {
+		for (add_it = 0; add_it < gee_collection_get_size (GEE_COLLECTION (add_collection)); add_it = add_it + 1) {
 			ValaMethod* add;
-			add = ((ValaMethod*) gee_iterator_get (add_it));
+			add = ((ValaMethod*) (gee_list_get (GEE_LIST (add_collection), add_it)));
 			{
 				{
 					GeeList* attr_collection;
-					GeeIterator* attr_it;
+					int attr_it;
 					attr_collection = gtkaml_class_definition_get_attrs (child_definition);
-					attr_it = gee_iterable_iterator (GEE_ITERABLE (attr_collection));
-					while (gee_iterator_next (attr_it)) {
+					for (attr_it = 0; attr_it < gee_collection_get_size (GEE_COLLECTION (attr_collection)); attr_it = attr_it + 1) {
 						GtkamlAttribute* attr;
-						attr = ((GtkamlAttribute*) gee_iterator_get (attr_it));
+						attr = ((GtkamlAttribute*) (gee_list_get (GEE_LIST (attr_collection), attr_it)));
 						{
 							GtkamlAttribute* _tmp0;
 							_tmp0 = NULL;
-							if (GTKAML_IS_SIMPLE_ATTRIBUTE (attr) && _vala_strcmp0 (gtkaml_attribute_get_name (attr), vala_symbol_get_name (VALA_SYMBOL (add))) == 0 && _vala_strcmp0 (gtkaml_simple_attribute_get_value (((_tmp0 = attr, (GTKAML_IS_SIMPLE_ATTRIBUTE (_tmp0) ? ((GtkamlSimpleAttribute*) _tmp0) : NULL)))), "true") == 0) {
+							if (GTKAML_IS_SIMPLE_ATTRIBUTE (attr) && _vala_strcmp0 (gtkaml_attribute_get_name (attr), vala_symbol_get_name (VALA_SYMBOL (add))) == 0 && _vala_strcmp0 (gtkaml_simple_attribute_get_value (((_tmp0 = attr, (GTKAML_IS_SIMPLE_ATTRIBUTE (_tmp0) ? ((GtkamlSimpleAttribute*) (_tmp0)) : NULL)))), "true") == 0) {
 								ValaMethod* _tmp2;
 								ValaMethod* _tmp1;
 								_tmp2 = NULL;
@@ -252,12 +243,10 @@ static void gtkaml_implicits_resolver_determine_add_method (GtkamlImplicitsResol
 							(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 						}
 					}
-					(attr_it == NULL ? NULL : (attr_it = (g_object_unref (attr_it), NULL)));
 				}
 				(add == NULL ? NULL : (add = (g_object_unref (add), NULL)));
 			}
 		}
-		(add_it == NULL ? NULL : (add_it = (g_object_unref (add_it), NULL)));
 	}
 	first_parameter = gtkaml_complex_attribute_new ("widget", child_definition);
 	method_matcher = gtkaml_method_matcher_new (self->priv->_implicits_store, gtkaml_class_definition_get_parent_container (child_definition), "container add method", first_parameter);
@@ -266,18 +255,16 @@ static void gtkaml_implicits_resolver_determine_add_method (GtkamlImplicitsResol
 		ValaMethod* _tmp3;
 		{
 			GeeList* method_collection;
-			GeeIterator* method_it;
+			int method_it;
 			method_collection = adds;
-			method_it = gee_iterable_iterator (GEE_ITERABLE (method_collection));
-			while (gee_iterator_next (method_it)) {
+			for (method_it = 0; method_it < gee_collection_get_size (GEE_COLLECTION (method_collection)); method_it = method_it + 1) {
 				ValaMethod* method;
-				method = ((ValaMethod*) gee_iterator_get (method_it));
+				method = ((ValaMethod*) (gee_list_get (GEE_LIST (method_collection), method_it)));
 				{
 					gtkaml_method_matcher_add_method (method_matcher, method);
 					(method == NULL ? NULL : (method = (g_object_unref (method), NULL)));
 				}
 			}
-			(method_it == NULL ? NULL : (method_it = (g_object_unref (method_it), NULL)));
 		}
 		_tmp3 = NULL;
 		determined_add = (_tmp3 = gtkaml_method_matcher_determine_matching_method (method_matcher), (determined_add == NULL ? NULL : (determined_add = (g_object_unref (determined_add), NULL))), _tmp3);
@@ -308,18 +295,16 @@ static void gtkaml_implicits_resolver_determine_add_method (GtkamlImplicitsResol
 	gtkaml_method_matcher_set_method_parameters (method_matcher, GTKAML_METHOD (new_method), determined_add);
 	{
 		GeeList* attr_collection;
-		GeeIterator* attr_it;
+		int attr_it;
 		attr_collection = to_remove;
-		attr_it = gee_iterable_iterator (GEE_ITERABLE (attr_collection));
-		while (gee_iterator_next (attr_it)) {
+		for (attr_it = 0; attr_it < gee_collection_get_size (GEE_COLLECTION (attr_collection)); attr_it = attr_it + 1) {
 			GtkamlAttribute* attr;
-			attr = ((GtkamlAttribute*) gee_iterator_get (attr_it));
+			attr = ((GtkamlAttribute*) (gee_list_get (GEE_LIST (attr_collection), attr_it)));
 			{
 				gee_collection_remove (GEE_COLLECTION (gtkaml_class_definition_get_attrs (child_definition)), attr);
 				(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 			}
 		}
-		(attr_it == NULL ? NULL : (attr_it = (g_object_unref (attr_it), NULL)));
 	}
 	gtkaml_class_definition_set_add_method (child_definition, new_method);
 	(adds == NULL ? NULL : (adds = (g_object_unref (adds), NULL)));
@@ -342,32 +327,30 @@ static void gtkaml_implicits_resolver_determine_construct_method (GtkamlImplicit
 	constructors = gtkaml_implicits_resolver_lookup_constructors (self, gtkaml_class_definition_get_base_type (class_definition));
 	determined_constructor = NULL;
 	new_method = gtkaml_construct_method_new ();
-	to_remove = GEE_LIST (gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	to_remove = GEE_LIST (gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 	/*pass one: see if we find an explicitly specified constructor*/
 	{
 		GeeList* constructor_collection;
-		GeeIterator* constructor_it;
+		int constructor_it;
 		constructor_collection = constructors;
-		constructor_it = gee_iterable_iterator (GEE_ITERABLE (constructor_collection));
-		while (gee_iterator_next (constructor_it)) {
+		for (constructor_it = 0; constructor_it < gee_collection_get_size (GEE_COLLECTION (constructor_collection)); constructor_it = constructor_it + 1) {
 			ValaMethod* constructor;
-			constructor = ((ValaMethod*) gee_iterator_get (constructor_it));
+			constructor = ((ValaMethod*) (gee_list_get (GEE_LIST (constructor_collection), constructor_it)));
 			{
 				{
 					GeeList* attr_collection;
-					GeeIterator* attr_it;
+					int attr_it;
 					attr_collection = gtkaml_class_definition_get_attrs (class_definition);
-					attr_it = gee_iterable_iterator (GEE_ITERABLE (attr_collection));
-					while (gee_iterator_next (attr_it)) {
+					for (attr_it = 0; attr_it < gee_collection_get_size (GEE_COLLECTION (attr_collection)); attr_it = attr_it + 1) {
 						GtkamlAttribute* attr;
-						attr = ((GtkamlAttribute*) gee_iterator_get (attr_it));
+						attr = ((GtkamlAttribute*) (gee_list_get (GEE_LIST (attr_collection), attr_it)));
 						{
 							char* _tmp0;
 							GtkamlAttribute* _tmp1;
 							gboolean _tmp2;
 							_tmp0 = NULL;
 							_tmp1 = NULL;
-							if ((_tmp2 = GTKAML_IS_SIMPLE_ATTRIBUTE (attr) && _vala_strcmp0 ((_tmp0 = g_strconcat (".new.", gtkaml_attribute_get_name (attr), NULL)), vala_symbol_get_name (VALA_SYMBOL (constructor))) == 0 && _vala_strcmp0 (gtkaml_simple_attribute_get_value (((_tmp1 = attr, (GTKAML_IS_SIMPLE_ATTRIBUTE (_tmp1) ? ((GtkamlSimpleAttribute*) _tmp1) : NULL)))), "true") == 0, (_tmp0 = (g_free (_tmp0), NULL)), _tmp2)) {
+							if ((_tmp2 = GTKAML_IS_SIMPLE_ATTRIBUTE (attr) && _vala_strcmp0 ((_tmp0 = g_strconcat (".new.", gtkaml_attribute_get_name (attr), NULL)), vala_symbol_get_name (VALA_SYMBOL (constructor))) == 0 && _vala_strcmp0 (gtkaml_simple_attribute_get_value (((_tmp1 = attr, (GTKAML_IS_SIMPLE_ATTRIBUTE (_tmp1) ? ((GtkamlSimpleAttribute*) (_tmp1)) : NULL)))), "true") == 0, (_tmp0 = (g_free (_tmp0), NULL)), _tmp2)) {
 								ValaMethod* _tmp4;
 								ValaMethod* _tmp3;
 								_tmp4 = NULL;
@@ -380,12 +363,10 @@ static void gtkaml_implicits_resolver_determine_construct_method (GtkamlImplicit
 							(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 						}
 					}
-					(attr_it == NULL ? NULL : (attr_it = (g_object_unref (attr_it), NULL)));
 				}
 				(constructor == NULL ? NULL : (constructor = (g_object_unref (constructor), NULL)));
 			}
 		}
-		(constructor_it == NULL ? NULL : (constructor_it = (g_object_unref (constructor_it), NULL)));
 	}
 	method_matcher = gtkaml_method_matcher_new (self->priv->_implicits_store, class_definition, "constructor", NULL);
 	/*pass two: the first who matches the most parameters + warning if there are more*/
@@ -393,18 +374,16 @@ static void gtkaml_implicits_resolver_determine_construct_method (GtkamlImplicit
 		ValaMethod* _tmp5;
 		{
 			GeeList* method_collection;
-			GeeIterator* method_it;
+			int method_it;
 			method_collection = constructors;
-			method_it = gee_iterable_iterator (GEE_ITERABLE (method_collection));
-			while (gee_iterator_next (method_it)) {
+			for (method_it = 0; method_it < gee_collection_get_size (GEE_COLLECTION (method_collection)); method_it = method_it + 1) {
 				ValaMethod* method;
-				method = ((ValaMethod*) gee_iterator_get (method_it));
+				method = ((ValaMethod*) (gee_list_get (GEE_LIST (method_collection), method_it)));
 				{
 					gtkaml_method_matcher_add_method (method_matcher, method);
 					(method == NULL ? NULL : (method = (g_object_unref (method), NULL)));
 				}
 			}
-			(method_it == NULL ? NULL : (method_it = (g_object_unref (method_it), NULL)));
 		}
 		_tmp5 = NULL;
 		determined_constructor = (_tmp5 = gtkaml_method_matcher_determine_matching_method (method_matcher), (determined_constructor == NULL ? NULL : (determined_constructor = (g_object_unref (determined_constructor), NULL))), _tmp5);
@@ -433,18 +412,16 @@ static void gtkaml_implicits_resolver_determine_construct_method (GtkamlImplicit
 	gtkaml_method_matcher_set_method_parameters (method_matcher, GTKAML_METHOD (new_method), determined_constructor);
 	{
 		GeeList* attr_collection;
-		GeeIterator* attr_it;
+		int attr_it;
 		attr_collection = to_remove;
-		attr_it = gee_iterable_iterator (GEE_ITERABLE (attr_collection));
-		while (gee_iterator_next (attr_it)) {
+		for (attr_it = 0; attr_it < gee_collection_get_size (GEE_COLLECTION (attr_collection)); attr_it = attr_it + 1) {
 			GtkamlAttribute* attr;
-			attr = ((GtkamlAttribute*) gee_iterator_get (attr_it));
+			attr = ((GtkamlAttribute*) (gee_list_get (GEE_LIST (attr_collection), attr_it)));
 			{
 				gee_collection_remove (GEE_COLLECTION (gtkaml_class_definition_get_attrs (class_definition)), attr);
 				(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 			}
 		}
-		(attr_it == NULL ? NULL : (attr_it = (g_object_unref (attr_it), NULL)));
 	}
 	gtkaml_class_definition_set_construct_method (class_definition, new_method);
 	(constructors == NULL ? NULL : (constructors = (g_object_unref (constructors), NULL)));
@@ -467,13 +444,12 @@ static void gtkaml_implicits_resolver_lookup_container_add_methods_for_class (Gt
 	}
 	/*recurse over base classes - ugly ugly ugly!*/
 	{
-		GeeCollection* dt_collection;
-		GeeIterator* dt_it;
+		GeeList* dt_collection;
+		int dt_it;
 		dt_collection = vala_class_get_base_types (container_class_holding_methods);
-		dt_it = gee_iterable_iterator (GEE_ITERABLE (dt_collection));
-		while (gee_iterator_next (dt_it)) {
+		for (dt_it = 0; dt_it < gee_collection_get_size (GEE_COLLECTION (dt_collection)); dt_it = dt_it + 1) {
 			ValaDataType* dt;
-			dt = ((ValaDataType*) gee_iterator_get (dt_it));
+			dt = ((ValaDataType*) (gee_list_get (GEE_LIST (dt_collection), dt_it)));
 			{
 				if (VALA_IS_UNRESOLVED_TYPE (dt)) {
 					ValaDataType* _tmp0;
@@ -481,14 +457,14 @@ static void gtkaml_implicits_resolver_lookup_container_add_methods_for_class (Gt
 					ValaDataType* _tmp1;
 					ValaClass* c;
 					_tmp0 = NULL;
-					utns = gtkaml_implicits_resolver_get_unresolved_type_ns (self, (_tmp0 = dt, (VALA_IS_UNRESOLVED_TYPE (_tmp0) ? ((ValaUnresolvedType*) _tmp0) : NULL)));
+					utns = gtkaml_implicits_resolver_get_unresolved_type_ns (self, (_tmp0 = dt, (VALA_IS_UNRESOLVED_TYPE (_tmp0) ? ((ValaUnresolvedType*) (_tmp0)) : NULL)));
 					if (utns == NULL) {
 						utns = (g_free (utns), NULL);
 						(dt == NULL ? NULL : (dt = (g_object_unref (dt), NULL)));
 						continue;
 					}
 					_tmp1 = NULL;
-					c = gtkaml_implicits_resolver_lookup_class (self, utns, vala_unresolved_symbol_get_name (vala_unresolved_type_get_unresolved_symbol (((_tmp1 = dt, (VALA_IS_UNRESOLVED_TYPE (_tmp1) ? ((ValaUnresolvedType*) _tmp1) : NULL))))));
+					c = gtkaml_implicits_resolver_lookup_class (self, utns, vala_unresolved_symbol_get_name (vala_unresolved_type_get_unresolved_symbol (((_tmp1 = dt, (VALA_IS_UNRESOLVED_TYPE (_tmp1) ? ((ValaUnresolvedType*) (_tmp1)) : NULL))))));
 					if (c != NULL) {
 						gtkaml_implicits_resolver_lookup_container_add_methods_for_class (self, ns, container_class_implicits_entry, utns, c, methods);
 					}
@@ -499,27 +475,24 @@ static void gtkaml_implicits_resolver_lookup_container_add_methods_for_class (Gt
 			}
 		}
 		(dt_collection == NULL ? NULL : (dt_collection = (g_object_unref (dt_collection), NULL)));
-		(dt_it == NULL ? NULL : (dt_it = (g_object_unref (dt_it), NULL)));
 	}
 	add_methods = gtkaml_implicits_store_get_adds (self->priv->_implicits_store, ns, vala_symbol_get_name (VALA_SYMBOL (container_class_implicits_entry)));
 	if (gee_collection_get_size (GEE_COLLECTION (add_methods)) != 0) {
 		{
 			GeeList* add_method_collection;
-			GeeIterator* add_method_it;
+			int add_method_it;
 			add_method_collection = add_methods;
-			add_method_it = gee_iterable_iterator (GEE_ITERABLE (add_method_collection));
-			while (gee_iterator_next (add_method_it)) {
+			for (add_method_it = 0; add_method_it < gee_collection_get_size (GEE_COLLECTION (add_method_collection)); add_method_it = add_method_it + 1) {
 				char* add_method;
-				add_method = ((char*) gee_iterator_get (add_method_it));
+				add_method = ((char*) (gee_list_get (GEE_LIST (add_method_collection), add_method_it)));
 				{
 					{
-						GeeCollection* method_collection;
-						GeeIterator* method_it;
-						method_collection = vala_class_get_methods (container_class_holding_methods);
-						method_it = gee_iterable_iterator (GEE_ITERABLE (method_collection));
-						while (gee_iterator_next (method_it)) {
+						GeeList* method_collection;
+						int method_it;
+						method_collection = vala_object_type_symbol_get_methods (VALA_OBJECT_TYPE_SYMBOL (container_class_holding_methods));
+						for (method_it = 0; method_it < gee_collection_get_size (GEE_COLLECTION (method_collection)); method_it = method_it + 1) {
 							ValaMethod* method;
-							method = ((ValaMethod*) gee_iterator_get (method_it));
+							method = ((ValaMethod*) (gee_list_get (GEE_LIST (method_collection), method_it)));
 							{
 								if (_vala_strcmp0 (vala_symbol_get_name (VALA_SYMBOL (method)), add_method) == 0) {
 									gee_collection_add (GEE_COLLECTION (methods), method);
@@ -531,12 +504,10 @@ static void gtkaml_implicits_resolver_lookup_container_add_methods_for_class (Gt
 							}
 						}
 						(method_collection == NULL ? NULL : (method_collection = (g_object_unref (method_collection), NULL)));
-						(method_it == NULL ? NULL : (method_it = (g_object_unref (method_it), NULL)));
 					}
 					add_method = (g_free (add_method), NULL);
 				}
 			}
-			(add_method_it == NULL ? NULL : (add_method_it = (g_object_unref (add_method_it), NULL)));
 		}
 	}
 	(add_methods == NULL ? NULL : (add_methods = (g_object_unref (add_methods), NULL)));
@@ -553,13 +524,12 @@ void gtkaml_implicits_resolver_lookup_container_add_methods (GtkamlImplicitsReso
 	}
 	gtkaml_implicits_resolver_lookup_container_add_methods_for_class (self, ns, container_class, ns, container_class, methods);
 	{
-		GeeCollection* dt_collection;
-		GeeIterator* dt_it;
+		GeeList* dt_collection;
+		int dt_it;
 		dt_collection = vala_class_get_base_types (container_class);
-		dt_it = gee_iterable_iterator (GEE_ITERABLE (dt_collection));
-		while (gee_iterator_next (dt_it)) {
+		for (dt_it = 0; dt_it < gee_collection_get_size (GEE_COLLECTION (dt_collection)); dt_it = dt_it + 1) {
 			ValaDataType* dt;
-			dt = ((ValaDataType*) gee_iterator_get (dt_it));
+			dt = ((ValaDataType*) (gee_list_get (GEE_LIST (dt_collection), dt_it)));
 			{
 				if (VALA_IS_UNRESOLVED_TYPE (dt)) {
 					ValaDataType* _tmp0;
@@ -567,14 +537,14 @@ void gtkaml_implicits_resolver_lookup_container_add_methods (GtkamlImplicitsReso
 					ValaDataType* _tmp1;
 					ValaClass* c;
 					_tmp0 = NULL;
-					utns = gtkaml_implicits_resolver_get_unresolved_type_ns (self, (_tmp0 = dt, (VALA_IS_UNRESOLVED_TYPE (_tmp0) ? ((ValaUnresolvedType*) _tmp0) : NULL)));
+					utns = gtkaml_implicits_resolver_get_unresolved_type_ns (self, (_tmp0 = dt, (VALA_IS_UNRESOLVED_TYPE (_tmp0) ? ((ValaUnresolvedType*) (_tmp0)) : NULL)));
 					if (utns == NULL) {
 						utns = (g_free (utns), NULL);
 						(dt == NULL ? NULL : (dt = (g_object_unref (dt), NULL)));
 						continue;
 					}
 					_tmp1 = NULL;
-					c = gtkaml_implicits_resolver_lookup_class (self, utns, vala_unresolved_symbol_get_name (vala_unresolved_type_get_unresolved_symbol (((_tmp1 = dt, (VALA_IS_UNRESOLVED_TYPE (_tmp1) ? ((ValaUnresolvedType*) _tmp1) : NULL))))));
+					c = gtkaml_implicits_resolver_lookup_class (self, utns, vala_unresolved_symbol_get_name (vala_unresolved_type_get_unresolved_symbol (((_tmp1 = dt, (VALA_IS_UNRESOLVED_TYPE (_tmp1) ? ((ValaUnresolvedType*) (_tmp1)) : NULL))))));
 					if (c != NULL) {
 						/*over inherited implicits definitions*/
 						gtkaml_implicits_resolver_lookup_container_add_methods (self, utns, c, methods);
@@ -590,7 +560,6 @@ void gtkaml_implicits_resolver_lookup_container_add_methods (GtkamlImplicitsReso
 			}
 		}
 		(dt_collection == NULL ? NULL : (dt_collection = (g_object_unref (dt_collection), NULL)));
-		(dt_it == NULL ? NULL : (dt_it = (g_object_unref (dt_it), NULL)));
 	}
 }
 
@@ -612,12 +581,11 @@ static void gtkaml_implicits_resolver_determine_attribute_types (GtkamlImplicits
 	g_return_if_fail (GTKAML_IS_CLASS_DEFINITION (class_definition));
 	{
 		GeeList* attr_collection;
-		GeeIterator* attr_it;
+		int attr_it;
 		attr_collection = gtkaml_class_definition_get_attrs (class_definition);
-		attr_it = gee_iterable_iterator (GEE_ITERABLE (attr_collection));
-		while (gee_iterator_next (attr_it)) {
+		for (attr_it = 0; attr_it < gee_collection_get_size (GEE_COLLECTION (attr_collection)); attr_it = attr_it + 1) {
 			GtkamlAttribute* attr;
-			attr = ((GtkamlAttribute*) gee_iterator_get (attr_it));
+			attr = ((GtkamlAttribute*) (gee_list_get (GEE_LIST (attr_collection), attr_it)));
 			{
 				ValaMember* _tmp0;
 				_tmp0 = NULL;
@@ -632,7 +600,6 @@ static void gtkaml_implicits_resolver_determine_attribute_types (GtkamlImplicits
 				(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 			}
 		}
-		(attr_it == NULL ? NULL : (attr_it = (g_object_unref (attr_it), NULL)));
 	}
 }
 
@@ -640,23 +607,22 @@ static void gtkaml_implicits_resolver_determine_attribute_types (GtkamlImplicits
 static ValaMember* gtkaml_implicits_resolver_member_lookup_inherited (GtkamlImplicitsResolver* self, ValaClass* clazz, const char* member) {
 	ValaSymbol* _tmp0;
 	ValaMember* result;
-	gpointer _tmp12;
+	ValaMember* _tmp12;
 	g_return_val_if_fail (GTKAML_IS_IMPLICITS_RESOLVER (self), NULL);
 	g_return_val_if_fail (VALA_IS_CLASS (clazz), NULL);
 	g_return_val_if_fail (member != NULL, NULL);
 	_tmp0 = NULL;
-	result = (_tmp0 = vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (clazz)), member), (VALA_IS_MEMBER (_tmp0) ? ((ValaMember*) _tmp0) : NULL));
+	result = (_tmp0 = vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (clazz)), member), (VALA_IS_MEMBER (_tmp0) ? ((ValaMember*) (_tmp0)) : NULL));
 	if (result != NULL) {
 		return result;
 	}
 	{
-		GeeCollection* dt_collection;
-		GeeIterator* dt_it;
+		GeeList* dt_collection;
+		int dt_it;
 		dt_collection = vala_class_get_base_types (clazz);
-		dt_it = gee_iterable_iterator (GEE_ITERABLE (dt_collection));
-		while (gee_iterator_next (dt_it)) {
+		for (dt_it = 0; dt_it < gee_collection_get_size (GEE_COLLECTION (dt_collection)); dt_it = dt_it + 1) {
 			ValaDataType* dt;
-			dt = ((ValaDataType*) gee_iterator_get (dt_it));
+			dt = ((ValaDataType*) (gee_list_get (GEE_LIST (dt_collection), dt_it)));
 			{
 				if (VALA_IS_UNRESOLVED_TYPE (dt)) {
 					const char* _tmp3;
@@ -669,17 +635,17 @@ static ValaMember* gtkaml_implicits_resolver_member_lookup_inherited (GtkamlImpl
 					ValaMember* _tmp9;
 					_tmp3 = NULL;
 					_tmp2 = NULL;
-					name = (_tmp3 = vala_unresolved_symbol_get_name (vala_unresolved_type_get_unresolved_symbol (((_tmp2 = dt, (VALA_IS_UNRESOLVED_TYPE (_tmp2) ? ((ValaUnresolvedType*) _tmp2) : NULL))))), (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
+					name = (_tmp3 = vala_unresolved_symbol_get_name (vala_unresolved_type_get_unresolved_symbol (((_tmp2 = dt, (VALA_IS_UNRESOLVED_TYPE (_tmp2) ? ((ValaUnresolvedType*) (_tmp2)) : NULL))))), (_tmp3 == NULL ? NULL : g_strdup (_tmp3)));
 					ns = NULL;
 					_tmp4 = NULL;
-					if (vala_unresolved_symbol_get_inner (vala_unresolved_type_get_unresolved_symbol (((_tmp4 = dt, (VALA_IS_UNRESOLVED_TYPE (_tmp4) ? ((ValaUnresolvedType*) _tmp4) : NULL))))) != NULL) {
+					if (vala_unresolved_symbol_get_inner (vala_unresolved_type_get_unresolved_symbol (((_tmp4 = dt, (VALA_IS_UNRESOLVED_TYPE (_tmp4) ? ((ValaUnresolvedType*) (_tmp4)) : NULL))))) != NULL) {
 						char* _tmp7;
 						const char* _tmp6;
 						ValaDataType* _tmp5;
 						_tmp7 = NULL;
 						_tmp6 = NULL;
 						_tmp5 = NULL;
-						ns = (_tmp7 = (_tmp6 = vala_unresolved_symbol_get_name (vala_unresolved_symbol_get_inner (vala_unresolved_type_get_unresolved_symbol (((_tmp5 = dt, (VALA_IS_UNRESOLVED_TYPE (_tmp5) ? ((ValaUnresolvedType*) _tmp5) : NULL)))))), (_tmp6 == NULL ? NULL : g_strdup (_tmp6))), (ns = (g_free (ns), NULL)), _tmp7);
+						ns = (_tmp7 = (_tmp6 = vala_unresolved_symbol_get_name (vala_unresolved_symbol_get_inner (vala_unresolved_type_get_unresolved_symbol (((_tmp5 = dt, (VALA_IS_UNRESOLVED_TYPE (_tmp5) ? ((ValaUnresolvedType*) (_tmp5)) : NULL)))))), (_tmp6 == NULL ? NULL : g_strdup (_tmp6))), (ns = (g_free (ns), NULL)), _tmp7);
 					} else {
 						char* _tmp8;
 						_tmp8 = NULL;
@@ -688,10 +654,10 @@ static ValaMember* gtkaml_implicits_resolver_member_lookup_inherited (GtkamlImpl
 					clazz = gtkaml_implicits_resolver_lookup_class (self, ns, name);
 					_tmp10 = NULL;
 					_tmp9 = NULL;
-					if (clazz != NULL && (NULL != (result = (_tmp10 = (_tmp9 = gtkaml_implicits_resolver_member_lookup_inherited (self, clazz, member), (VALA_IS_MEMBER (_tmp9) ? ((ValaMember*) _tmp9) : NULL)), (result == NULL ? NULL : (result = (g_object_unref (result), NULL))), _tmp10)))) {
+					if (clazz != NULL && (NULL != (result = (_tmp10 = (_tmp9 = gtkaml_implicits_resolver_member_lookup_inherited (self, clazz, member), (VALA_IS_MEMBER (_tmp9) ? ((ValaMember*) (_tmp9)) : NULL)), (result == NULL ? NULL : (result = (g_object_unref (result), NULL))), _tmp10)))) {
 						ValaMember* _tmp11;
 						_tmp11 = NULL;
-						return (_tmp11 = result, (name = (g_free (name), NULL)), (ns = (g_free (ns), NULL)), (clazz == NULL ? NULL : (clazz = (g_object_unref (clazz), NULL))), (dt == NULL ? NULL : (dt = (g_object_unref (dt), NULL))), (dt_collection == NULL ? NULL : (dt_collection = (g_object_unref (dt_collection), NULL))), (dt_it == NULL ? NULL : (dt_it = (g_object_unref (dt_it), NULL))), _tmp11);
+						return (_tmp11 = result, (name = (g_free (name), NULL)), (ns = (g_free (ns), NULL)), (clazz == NULL ? NULL : (clazz = (g_object_unref (clazz), NULL))), (dt == NULL ? NULL : (dt = (g_object_unref (dt), NULL))), (dt_collection == NULL ? NULL : (dt_collection = (g_object_unref (dt_collection), NULL))), _tmp11);
 					}
 					name = (g_free (name), NULL);
 					ns = (g_free (ns), NULL);
@@ -701,8 +667,8 @@ static ValaMember* gtkaml_implicits_resolver_member_lookup_inherited (GtkamlImpl
 			}
 		}
 		(dt_collection == NULL ? NULL : (dt_collection = (g_object_unref (dt_collection), NULL)));
-		(dt_it == NULL ? NULL : (dt_it = (g_object_unref (dt_it), NULL)));
 	}
+	_tmp12 = NULL;
 	return (_tmp12 = NULL, (result == NULL ? NULL : (result = (g_object_unref (result), NULL))), _tmp12);
 }
 
@@ -712,13 +678,12 @@ static ValaClass* gtkaml_implicits_resolver_lookup_class (GtkamlImplicitsResolve
 	g_return_val_if_fail (xmlNamespace != NULL, NULL);
 	g_return_val_if_fail (name != NULL, NULL);
 	{
-		GeeCollection* ns_collection;
-		GeeIterator* ns_it;
+		GeeList* ns_collection;
+		int ns_it;
 		ns_collection = vala_namespace_get_namespaces (vala_code_context_get_root (self->priv->_context));
-		ns_it = gee_iterable_iterator (GEE_ITERABLE (ns_collection));
-		while (gee_iterator_next (ns_it)) {
+		for (ns_it = 0; ns_it < gee_collection_get_size (GEE_COLLECTION (ns_collection)); ns_it = ns_it + 1) {
 			ValaNamespace* ns;
-			ns = ((ValaNamespace*) gee_iterator_get (ns_it));
+			ns = ((ValaNamespace*) (gee_list_get (GEE_LIST (ns_collection), ns_it)));
 			{
 				if ((vala_symbol_get_name (VALA_SYMBOL (ns)) == NULL && xmlNamespace == NULL) || _vala_strcmp0 (vala_symbol_get_name (VALA_SYMBOL (ns)), xmlNamespace) == 0) {
 					ValaSymbol* s;
@@ -730,7 +695,7 @@ static ValaClass* gtkaml_implicits_resolver_lookup_class (GtkamlImplicitsResolve
 						_tmp1 = NULL;
 						_tmp0 = NULL;
 						_tmp2 = NULL;
-						return (_tmp2 = (_tmp1 = (_tmp0 = s, (VALA_IS_CLASS (_tmp0) ? ((ValaClass*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (s == NULL ? NULL : (s = (g_object_unref (s), NULL))), (ns == NULL ? NULL : (ns = (g_object_unref (ns), NULL))), (ns_collection == NULL ? NULL : (ns_collection = (g_object_unref (ns_collection), NULL))), (ns_it == NULL ? NULL : (ns_it = (g_object_unref (ns_it), NULL))), _tmp2);
+						return (_tmp2 = (_tmp1 = (_tmp0 = s, (VALA_IS_CLASS (_tmp0) ? ((ValaClass*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (s == NULL ? NULL : (s = (g_object_unref (s), NULL))), (ns == NULL ? NULL : (ns = (g_object_unref (ns), NULL))), (ns_collection == NULL ? NULL : (ns_collection = (g_object_unref (ns_collection), NULL))), _tmp2);
 					}
 					(s == NULL ? NULL : (s = (g_object_unref (s), NULL)));
 				}
@@ -738,7 +703,6 @@ static ValaClass* gtkaml_implicits_resolver_lookup_class (GtkamlImplicitsResolve
 			}
 		}
 		(ns_collection == NULL ? NULL : (ns_collection = (g_object_unref (ns_collection), NULL)));
-		(ns_it == NULL ? NULL : (ns_it = (g_object_unref (ns_it), NULL)));
 	}
 	return NULL;
 }
@@ -748,15 +712,14 @@ static GeeList* gtkaml_implicits_resolver_lookup_constructors (GtkamlImplicitsRe
 	GeeArrayList* constructors;
 	g_return_val_if_fail (GTKAML_IS_IMPLICITS_RESOLVER (self), NULL);
 	g_return_val_if_fail (VALA_IS_CLASS (clazz), NULL);
-	constructors = gee_array_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal);
+	constructors = gee_array_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal);
 	{
-		GeeCollection* m_collection;
-		GeeIterator* m_it;
-		m_collection = vala_class_get_methods (clazz);
-		m_it = gee_iterable_iterator (GEE_ITERABLE (m_collection));
-		while (gee_iterator_next (m_it)) {
+		GeeList* m_collection;
+		int m_it;
+		m_collection = vala_object_type_symbol_get_methods (VALA_OBJECT_TYPE_SYMBOL (clazz));
+		for (m_it = 0; m_it < gee_collection_get_size (GEE_COLLECTION (m_collection)); m_it = m_it + 1) {
 			ValaMethod* m;
-			m = ((ValaMethod*) gee_iterator_get (m_it));
+			m = ((ValaMethod*) (gee_list_get (GEE_LIST (m_collection), m_it)));
 			{
 				/*todo: if m is ConstructMethod ?*/
 				if (g_str_has_prefix (vala_symbol_get_name (VALA_SYMBOL (m)), ".new")) {
@@ -766,7 +729,6 @@ static GeeList* gtkaml_implicits_resolver_lookup_constructors (GtkamlImplicitsRe
 			}
 		}
 		(m_collection == NULL ? NULL : (m_collection = (g_object_unref (m_collection), NULL)));
-		(m_it == NULL ? NULL : (m_it = (g_object_unref (m_it), NULL)));
 	}
 	return GEE_LIST (constructors);
 }
@@ -842,7 +804,7 @@ static void gtkaml_implicits_resolver_class_init (GtkamlImplicitsResolverClass *
 }
 
 
-static void gtkaml_implicits_resolver_init (GtkamlImplicitsResolver * self) {
+static void gtkaml_implicits_resolver_instance_init (GtkamlImplicitsResolver * self) {
 	self->priv = GTKAML_IMPLICITS_RESOLVER_GET_PRIVATE (self);
 }
 
@@ -859,7 +821,7 @@ static void gtkaml_implicits_resolver_dispose (GObject * obj) {
 GType gtkaml_implicits_resolver_get_type (void) {
 	static GType gtkaml_implicits_resolver_type_id = 0;
 	if (G_UNLIKELY (gtkaml_implicits_resolver_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GtkamlImplicitsResolverClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_implicits_resolver_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlImplicitsResolver), 0, (GInstanceInitFunc) gtkaml_implicits_resolver_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GtkamlImplicitsResolverClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_implicits_resolver_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlImplicitsResolver), 0, (GInstanceInitFunc) gtkaml_implicits_resolver_instance_init };
 		gtkaml_implicits_resolver_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlImplicitsResolver", &g_define_type_info, 0);
 	}
 	return gtkaml_implicits_resolver_type_id;
