@@ -103,7 +103,7 @@ static void gtkaml_implicits_parameter_class_init (GtkamlImplicitsParameterClass
 }
 
 
-static void gtkaml_implicits_parameter_init (GtkamlImplicitsParameter * self) {
+static void gtkaml_implicits_parameter_instance_init (GtkamlImplicitsParameter * self) {
 }
 
 
@@ -119,7 +119,7 @@ static void gtkaml_implicits_parameter_dispose (GObject * obj) {
 GType gtkaml_implicits_parameter_get_type (void) {
 	static GType gtkaml_implicits_parameter_type_id = 0;
 	if (G_UNLIKELY (gtkaml_implicits_parameter_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GtkamlImplicitsParameterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_implicits_parameter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlImplicitsParameter), 0, (GInstanceInitFunc) gtkaml_implicits_parameter_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GtkamlImplicitsParameterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_implicits_parameter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlImplicitsParameter), 0, (GInstanceInitFunc) gtkaml_implicits_parameter_instance_init };
 		gtkaml_implicits_parameter_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlImplicitsParameter", &g_define_type_info, 0);
 	}
 	return gtkaml_implicits_parameter_type_id;
@@ -132,20 +132,50 @@ static gboolean gtkaml_key_file_wrapper_has_key (GtkamlKeyFileWrapper* self, con
 	g_return_val_if_fail (group != NULL, FALSE);
 	g_return_val_if_fail (key != NULL, FALSE);
 	inner_error = NULL;
-	return g_key_file_has_key (self->key_file, group, key, &inner_error);
+	{
+		return g_key_file_has_key (self->key_file, group, key, &inner_error);
+	}
+	goto __finally4;
+	__catch4_g_key_file_error:
+	{
+		GError * e;
+		e = inner_error;
+		inner_error = NULL;
+		{
+			return FALSE;
+		}
+	}
+	__finally4:
+	;
 }
 
 
 static char** gtkaml_key_file_wrapper_get_string_list (GtkamlKeyFileWrapper* self, const char* group, const char* key, int* result_length1) {
 	GError * inner_error;
-	gint _tmp0;
-	char** _tmp1;
 	g_return_val_if_fail (GTKAML_IS_KEY_FILE_WRAPPER (self), NULL);
 	g_return_val_if_fail (group != NULL, NULL);
 	g_return_val_if_fail (key != NULL, NULL);
 	inner_error = NULL;
-	_tmp1 = NULL;
-	return (_tmp1 = g_key_file_get_string_list (self->key_file, group, key, &_tmp0, &inner_error), *result_length1 = _tmp0, _tmp1);
+	{
+		gint _tmp0;
+		char** _tmp1;
+		_tmp1 = NULL;
+		return (_tmp1 = g_key_file_get_string_list (self->key_file, group, key, &_tmp0, &inner_error), (*result_length1) = _tmp0, _tmp1);
+	}
+	goto __finally5;
+	__catch5_g_error:
+	{
+		GError * e;
+		e = inner_error;
+		inner_error = NULL;
+		{
+			char** _tmp3;
+			_tmp3 = NULL;
+			return (_tmp3 = g_new0 (char*, 0 + 1), (*result_length1) = 0, _tmp3);
+		}
+	}
+	__finally5:
+	;
 }
 
 
@@ -184,7 +214,7 @@ static void gtkaml_key_file_wrapper_class_init (GtkamlKeyFileWrapperClass * klas
 }
 
 
-static void gtkaml_key_file_wrapper_init (GtkamlKeyFileWrapper * self) {
+static void gtkaml_key_file_wrapper_instance_init (GtkamlKeyFileWrapper * self) {
 }
 
 
@@ -199,7 +229,7 @@ static void gtkaml_key_file_wrapper_dispose (GObject * obj) {
 static GType gtkaml_key_file_wrapper_get_type (void) {
 	static GType gtkaml_key_file_wrapper_type_id = 0;
 	if (G_UNLIKELY (gtkaml_key_file_wrapper_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GtkamlKeyFileWrapperClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_key_file_wrapper_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlKeyFileWrapper), 0, (GInstanceInitFunc) gtkaml_key_file_wrapper_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GtkamlKeyFileWrapperClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_key_file_wrapper_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlKeyFileWrapper), 0, (GInstanceInitFunc) gtkaml_key_file_wrapper_instance_init };
 		gtkaml_key_file_wrapper_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlKeyFileWrapper", &g_define_type_info, 0);
 	}
 	return gtkaml_key_file_wrapper_type_id;
@@ -208,7 +238,7 @@ static GType gtkaml_key_file_wrapper_get_type (void) {
 
 GeeReadOnlyList* gtkaml_implicits_store_get_implicits_dirs (GtkamlImplicitsStore* self) {
 	g_return_val_if_fail (GTKAML_IS_IMPLICITS_STORE (self), NULL);
-	return gee_read_only_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, self->priv->implicits_dirs);
+	return gee_read_only_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, self->priv->implicits_dirs);
 }
 
 
@@ -225,18 +255,17 @@ static GeeList* gtkaml_implicits_store_get_ns (GtkamlImplicitsStore* self, const
 	g_return_val_if_fail (ns != NULL, NULL);
 	inner_error = NULL;
 	if (gee_map_contains (self->priv->loaded_ns, ns)) {
-		return ((GeeList*) gee_map_get (self->priv->loaded_ns, ns));
+		return ((GeeList*) (gee_map_get (self->priv->loaded_ns, ns)));
 	} else {
 		GeeArrayList* key_file_list;
-		key_file_list = gee_array_list_new (GTKAML_TYPE_KEY_FILE_WRAPPER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal);
+		key_file_list = gee_array_list_new (GTKAML_TYPE_KEY_FILE_WRAPPER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal);
 		{
 			GeeList* implicits_dir_collection;
-			GeeIterator* implicits_dir_it;
+			int implicits_dir_it;
 			implicits_dir_collection = self->priv->implicits_dirs;
-			implicits_dir_it = gee_iterable_iterator (GEE_ITERABLE (implicits_dir_collection));
-			while (gee_iterator_next (implicits_dir_it)) {
+			for (implicits_dir_it = 0; implicits_dir_it < gee_collection_get_size (GEE_COLLECTION (implicits_dir_collection)); implicits_dir_it = implicits_dir_it + 1) {
 				char* implicits_dir;
-				implicits_dir = ((char*) gee_iterator_get (implicits_dir_it));
+				implicits_dir = ((char*) (gee_list_get (GEE_LIST (implicits_dir_collection), implicits_dir_it)));
 				{
 					char* _tmp1;
 					char* _tmp2;
@@ -250,12 +279,12 @@ static GeeList* gtkaml_implicits_store_get_ns (GtkamlImplicitsStore* self, const
 						{
 							g_key_file_load_from_file (key_file_wrapper->key_file, file_name, G_KEY_FILE_NONE, &inner_error);
 							if (inner_error != NULL) {
-								goto __catch4_g_error;
+								goto __catch6_g_error;
 							}
 							gee_collection_add (GEE_COLLECTION (key_file_list), key_file_wrapper);
 						}
-						goto __finally4;
-						__catch4_g_error:
+						goto __finally6;
+						__catch6_g_error:
 						{
 							GError * e;
 							e = inner_error;
@@ -267,7 +296,7 @@ static GeeList* gtkaml_implicits_store_get_ns (GtkamlImplicitsStore* self, const
 								_tmp3 = (g_free (_tmp3), NULL);
 							}
 						}
-						__finally4:
+						__finally6:
 						;
 						(key_file_wrapper == NULL ? NULL : (key_file_wrapper = (g_object_unref (key_file_wrapper), NULL)));
 					}
@@ -275,10 +304,9 @@ static GeeList* gtkaml_implicits_store_get_ns (GtkamlImplicitsStore* self, const
 					file_name = (g_free (file_name), NULL);
 				}
 			}
-			(implicits_dir_it == NULL ? NULL : (implicits_dir_it = (g_object_unref (implicits_dir_it), NULL)));
 		}
 		/*even an empty list does it: so that we don't scan the directories again*/
-		gee_map_set (self->priv->loaded_ns, ns, key_file_list);
+		gee_map_set (self->priv->loaded_ns, ns, GEE_LIST (key_file_list));
 		return GEE_LIST (key_file_list);
 	}
 }
@@ -291,16 +319,15 @@ GeeList* gtkaml_implicits_store_get_adds (GtkamlImplicitsStore* self, const char
 	g_return_val_if_fail (GTKAML_IS_IMPLICITS_STORE (self), NULL);
 	g_return_val_if_fail (ns != NULL, NULL);
 	g_return_val_if_fail (class_name != NULL, NULL);
-	adds = GEE_LIST (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, g_direct_equal));
+	adds = GEE_LIST (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_direct_equal));
 	kf_ns = gtkaml_implicits_store_get_ns (self, ns);
 	{
 		GeeList* kfw_collection;
-		GeeIterator* kfw_it;
+		int kfw_it;
 		kfw_collection = kf_ns;
-		kfw_it = gee_iterable_iterator (GEE_ITERABLE (kfw_collection));
-		while (gee_iterator_next (kfw_it)) {
+		for (kfw_it = 0; kfw_it < gee_collection_get_size (GEE_COLLECTION (kfw_collection)); kfw_it = kfw_it + 1) {
 			GtkamlKeyFileWrapper* kfw;
-			kfw = ((GtkamlKeyFileWrapper*) gee_iterator_get (kfw_it));
+			kfw = ((GtkamlKeyFileWrapper*) (gee_list_get (GEE_LIST (kfw_collection), kfw_it)));
 			{
 				if (gtkaml_key_file_wrapper_has_key (kfw, class_name, "adds")) {
 					char** _tmp1;
@@ -311,8 +338,10 @@ GeeList* gtkaml_implicits_store_get_adds (GtkamlImplicitsStore* self, const char
 					kf_adds = (_tmp1 = gtkaml_key_file_wrapper_get_string_list (kfw, class_name, "adds", &_tmp0), kf_adds_length1 = _tmp0, _tmp1);
 					{
 						char** add_collection;
+						int add_collection_length1;
 						int add_it;
 						add_collection = kf_adds;
+						add_collection_length1 = kf_adds_length1;
 						for (add_it = 0; (kf_adds_length1 != -1 && add_it < kf_adds_length1) || (kf_adds_length1 == -1 && add_collection[add_it] != NULL); add_it = add_it + 1) {
 							const char* _tmp2;
 							char* add;
@@ -325,12 +354,11 @@ GeeList* gtkaml_implicits_store_get_adds (GtkamlImplicitsStore* self, const char
 							}
 						}
 					}
-					kf_adds = (_vala_array_free (kf_adds, kf_adds_length1, ((GDestroyNotify) g_free)), NULL);
+					kf_adds = (_vala_array_free (kf_adds, kf_adds_length1, ((GDestroyNotify) (g_free))), NULL);
 				}
 				(kfw == NULL ? NULL : (kfw = (g_object_unref (kfw), NULL)));
 			}
 		}
-		(kfw_it == NULL ? NULL : (kfw_it = (g_object_unref (kfw_it), NULL)));
 	}
 	_tmp3 = NULL;
 	return (_tmp3 = adds, (kf_ns == NULL ? NULL : (kf_ns = (g_object_unref (kf_ns), NULL))), _tmp3);
@@ -343,15 +371,14 @@ GeeList* gtkaml_implicits_store_get_method_parameters (GtkamlImplicitsStore* sel
 	g_return_val_if_fail (ns != NULL, NULL);
 	g_return_val_if_fail (class_name != NULL, NULL);
 	g_return_val_if_fail (method_name != NULL, NULL);
-	parameters = GEE_LIST (gee_array_list_new (GTKAML_TYPE_IMPLICITS_PARAMETER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	parameters = GEE_LIST (gee_array_list_new (GTKAML_TYPE_IMPLICITS_PARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 	{
 		GeeList* kfw_collection;
-		GeeIterator* kfw_it;
+		int kfw_it;
 		kfw_collection = gtkaml_implicits_store_get_ns (self, ns);
-		kfw_it = gee_iterable_iterator (GEE_ITERABLE (kfw_collection));
-		while (gee_iterator_next (kfw_it)) {
+		for (kfw_it = 0; kfw_it < gee_collection_get_size (GEE_COLLECTION (kfw_collection)); kfw_it = kfw_it + 1) {
 			GtkamlKeyFileWrapper* kfw;
-			kfw = ((GtkamlKeyFileWrapper*) gee_iterator_get (kfw_it));
+			kfw = ((GtkamlKeyFileWrapper*) (gee_list_get (GEE_LIST (kfw_collection), kfw_it)));
 			{
 				if (gtkaml_key_file_wrapper_has_key (kfw, class_name, method_name)) {
 					char** _tmp1;
@@ -363,8 +390,10 @@ GeeList* gtkaml_implicits_store_get_method_parameters (GtkamlImplicitsStore* sel
 					kf_parameters = (_tmp1 = gtkaml_key_file_wrapper_get_string_list (kfw, class_name, method_name, &_tmp0), kf_parameters_length1 = _tmp0, _tmp1);
 					{
 						char** parameter_collection;
+						int parameter_collection_length1;
 						int parameter_it;
 						parameter_collection = kf_parameters;
+						parameter_collection_length1 = kf_parameters_length1;
 						for (parameter_it = 0; (kf_parameters_length1 != -1 && parameter_it < kf_parameters_length1) || (kf_parameters_length1 == -1 && parameter_collection[parameter_it] != NULL); parameter_it = parameter_it + 1) {
 							const char* _tmp7;
 							char* parameter;
@@ -392,18 +421,17 @@ GeeList* gtkaml_implicits_store_get_method_parameters (GtkamlImplicitsStore* sel
 								gee_collection_add (GEE_COLLECTION (parameters), implicits_parameter);
 								parameter = (g_free (parameter), NULL);
 								(implicits_parameter == NULL ? NULL : (implicits_parameter = (g_object_unref (implicits_parameter), NULL)));
-								name_value = (_vala_array_free (name_value, name_value_length1, ((GDestroyNotify) g_free)), NULL);
+								name_value = (_vala_array_free (name_value, name_value_length1, ((GDestroyNotify) (g_free))), NULL);
 							}
 						}
 					}
 					_tmp8 = NULL;
-					return (_tmp8 = parameters, (kf_parameters = (_vala_array_free (kf_parameters, kf_parameters_length1, ((GDestroyNotify) g_free)), NULL)), (kfw == NULL ? NULL : (kfw = (g_object_unref (kfw), NULL))), (kfw_collection == NULL ? NULL : (kfw_collection = (g_object_unref (kfw_collection), NULL))), (kfw_it == NULL ? NULL : (kfw_it = (g_object_unref (kfw_it), NULL))), _tmp8);
+					return (_tmp8 = parameters, (kf_parameters = (_vala_array_free (kf_parameters, kf_parameters_length1, ((GDestroyNotify) (g_free))), NULL)), (kfw == NULL ? NULL : (kfw = (g_object_unref (kfw), NULL))), (kfw_collection == NULL ? NULL : (kfw_collection = (g_object_unref (kfw_collection), NULL))), _tmp8);
 				}
 				(kfw == NULL ? NULL : (kfw = (g_object_unref (kfw), NULL)));
 			}
 		}
 		(kfw_collection == NULL ? NULL : (kfw_collection = (g_object_unref (kfw_collection), NULL)));
-		(kfw_it == NULL ? NULL : (kfw_it = (g_object_unref (kfw_it), NULL)));
 	}
 	return parameters;
 }
@@ -418,7 +446,7 @@ GeeList* gtkaml_implicits_store_determine_parameter_names_and_default_values (Gt
 	const char* _tmp1;
 	char* method_name;
 	GeeList* result_array;
-	GeeArrayList* _tmp8;
+	GeeList* _tmp8;
 	g_return_val_if_fail (GTKAML_IS_IMPLICITS_STORE (self), NULL);
 	g_return_val_if_fail (GTKAML_IS_CLASS_DEFINITION (class_definition), NULL);
 	g_return_val_if_fail (VALA_IS_METHOD (method), NULL);
@@ -426,7 +454,7 @@ GeeList* gtkaml_implicits_store_determine_parameter_names_and_default_values (Gt
 	_tmp0 = NULL;
 	clazz = (_tmp0 = vala_symbol_get_name (vala_symbol_get_parent_symbol (VALA_SYMBOL (method))), (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
 	/*stderr.printf ("determine_parameter_names_and_default_values %s %s of %s.%s\n", class_definition.base_full_name, method.name, ns, clazz);*/
-	result = gee_array_list_new (GTKAML_TYPE_IMPLICITS_PARAMETER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal);
+	result = gee_array_list_new (GTKAML_TYPE_IMPLICITS_PARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal);
 	_tmp1 = NULL;
 	method_name = (_tmp1 = vala_symbol_get_name (VALA_SYMBOL (method)), (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
 	if (g_str_has_prefix (vala_symbol_get_name (VALA_SYMBOL (method)), ".new")) {
@@ -434,7 +462,7 @@ GeeList* gtkaml_implicits_store_determine_parameter_names_and_default_values (Gt
 		char* _tmp2;
 		_tmp3 = NULL;
 		_tmp2 = NULL;
-		method_name = (_tmp3 = (_tmp2 = g_utf8_offset_to_pointer (vala_symbol_get_name (VALA_SYMBOL (method)), ((glong) 1)), g_strndup (_tmp2, g_utf8_offset_to_pointer (_tmp2, g_utf8_strlen (vala_symbol_get_name (VALA_SYMBOL (method)), -1) - 1) - _tmp2)), (method_name = (g_free (method_name), NULL)), _tmp3);
+		method_name = (_tmp3 = (_tmp2 = g_utf8_offset_to_pointer (vala_symbol_get_name (VALA_SYMBOL (method)), ((glong) (1))), g_strndup (_tmp2, g_utf8_offset_to_pointer (_tmp2, g_utf8_strlen (vala_symbol_get_name (VALA_SYMBOL (method)), -1) - 1) - _tmp2)), (method_name = (g_free (method_name), NULL)), _tmp3);
 	} else {
 		char* _tmp4;
 		_tmp4 = NULL;
@@ -444,12 +472,11 @@ GeeList* gtkaml_implicits_store_determine_parameter_names_and_default_values (Gt
 	if (gee_collection_get_size (GEE_COLLECTION (result_array)) != 0) {
 		{
 			GeeList* result_item_collection;
-			GeeIterator* result_item_it;
+			int result_item_it;
 			result_item_collection = result_array;
-			result_item_it = gee_iterable_iterator (GEE_ITERABLE (result_item_collection));
-			while (gee_iterator_next (result_item_it)) {
+			for (result_item_it = 0; result_item_it < gee_collection_get_size (GEE_COLLECTION (result_item_collection)); result_item_it = result_item_it + 1) {
 				GtkamlImplicitsParameter* result_item;
-				result_item = ((GtkamlImplicitsParameter*) gee_iterator_get (result_item_it));
+				result_item = ((GtkamlImplicitsParameter*) (gee_list_get (GEE_LIST (result_item_collection), result_item_it)));
 				{
 					if (result_item->default_value != NULL) {
 					}
@@ -458,17 +485,15 @@ GeeList* gtkaml_implicits_store_determine_parameter_names_and_default_values (Gt
 					(result_item == NULL ? NULL : (result_item = (g_object_unref (result_item), NULL)));
 				}
 			}
-			(result_item_it == NULL ? NULL : (result_item_it = (g_object_unref (result_item_it), NULL)));
 		}
 	} else {
 		{
-			GeeCollection* p_collection;
-			GeeIterator* p_it;
+			GeeList* p_collection;
+			int p_it;
 			p_collection = vala_method_get_parameters (method);
-			p_it = gee_iterable_iterator (GEE_ITERABLE (p_collection));
-			while (gee_iterator_next (p_it)) {
+			for (p_it = 0; p_it < gee_collection_get_size (GEE_COLLECTION (p_collection)); p_it = p_it + 1) {
 				ValaFormalParameter* p;
-				p = ((ValaFormalParameter*) gee_iterator_get (p_it));
+				p = ((ValaFormalParameter*) (gee_list_get (GEE_LIST (p_collection), p_it)));
 				{
 					if (!vala_formal_parameter_get_ellipsis (p)) {
 						GtkamlImplicitsParameter* new_implicits_parameter;
@@ -490,11 +515,10 @@ GeeList* gtkaml_implicits_store_determine_parameter_names_and_default_values (Gt
 				}
 			}
 			(p_collection == NULL ? NULL : (p_collection = (g_object_unref (p_collection), NULL)));
-			(p_it == NULL ? NULL : (p_it = (g_object_unref (p_it), NULL)));
 		}
 	}
 	_tmp8 = NULL;
-	return GEE_LIST ((_tmp8 = result, (ns = (g_free (ns), NULL)), (clazz = (g_free (clazz), NULL)), (method_name = (g_free (method_name), NULL)), (result_array == NULL ? NULL : (result_array = (g_object_unref (result_array), NULL))), _tmp8));
+	return (_tmp8 = GEE_LIST (result), (ns = (g_free (ns), NULL)), (clazz = (g_free (clazz), NULL)), (method_name = (g_free (method_name), NULL)), (result_array == NULL ? NULL : (result_array = (g_object_unref (result_array), NULL))), _tmp8);
 }
 
 
@@ -515,10 +539,10 @@ static void gtkaml_implicits_store_class_init (GtkamlImplicitsStoreClass * klass
 }
 
 
-static void gtkaml_implicits_store_init (GtkamlImplicitsStore * self) {
+static void gtkaml_implicits_store_instance_init (GtkamlImplicitsStore * self) {
 	self->priv = GTKAML_IMPLICITS_STORE_GET_PRIVATE (self);
-	self->priv->implicits_dirs = GEE_LIST (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, g_str_equal));
-	self->priv->loaded_ns = GEE_MAP (gee_hash_map_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, GEE_TYPE_LIST, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_str_hash, g_str_equal, g_direct_equal));
+	self->priv->implicits_dirs = GEE_LIST (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_str_equal));
+	self->priv->loaded_ns = GEE_MAP (gee_hash_map_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, GEE_TYPE_LIST, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_str_hash, g_str_equal, g_direct_equal));
 }
 
 
@@ -534,7 +558,7 @@ static void gtkaml_implicits_store_dispose (GObject * obj) {
 GType gtkaml_implicits_store_get_type (void) {
 	static GType gtkaml_implicits_store_type_id = 0;
 	if (G_UNLIKELY (gtkaml_implicits_store_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GtkamlImplicitsStoreClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_implicits_store_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlImplicitsStore), 0, (GInstanceInitFunc) gtkaml_implicits_store_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GtkamlImplicitsStoreClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_implicits_store_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlImplicitsStore), 0, (GInstanceInitFunc) gtkaml_implicits_store_instance_init };
 		gtkaml_implicits_store_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlImplicitsStore", &g_define_type_info, 0);
 	}
 	return gtkaml_implicits_store_type_id;
@@ -546,12 +570,12 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 		int i;
 		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) array)[i] != NULL)
-			destroy_func (((gpointer*) array)[i]);
+			if (((gpointer*) (array))[i] != NULL)
+			destroy_func (((gpointer*) (array))[i]);
 		}
 		else
-		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) array)[i]);
+		for (i = 0; ((gpointer*) (array))[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) (array))[i]);
 		}
 	}
 	g_free (array);
