@@ -125,12 +125,11 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 	/*stderr.printf ("===%d candidates\n", methods.size);*/
 	{
 		GeeList* method_collection;
-		GeeIterator* method_it;
+		int method_it;
 		method_collection = self->priv->methods;
-		method_it = gee_iterable_iterator (GEE_ITERABLE (method_collection));
-		while (gee_iterator_next (method_it)) {
+		for (method_it = 0; method_it < gee_collection_get_size (GEE_COLLECTION (method_collection)); method_it = method_it + 1) {
 			ValaMethod* method;
-			method = ((ValaMethod*) gee_iterator_get (method_it));
+			method = ((ValaMethod*) (gee_list_get (GEE_LIST (method_collection), method_it)));
 			{
 				GeeList* parameters;
 				gint current_matches;
@@ -140,27 +139,25 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 				parameters = gtkaml_implicits_store_determine_parameter_names_and_default_values (self->priv->_implicits_store, self->priv->_class_owning_method, method);
 				current_matches = 0;
 				current_matches_defaulted = 0;
-				current_defaulted_parameters = GEE_LIST (gee_array_list_new (GTKAML_TYPE_IMPLICITS_PARAMETER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+				current_defaulted_parameters = GEE_LIST (gee_array_list_new (GTKAML_TYPE_IMPLICITS_PARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 				{
 					GeeList* parameter_collection;
-					GeeIterator* parameter_it;
+					int parameter_it;
 					parameter_collection = parameters;
-					parameter_it = gee_iterable_iterator (GEE_ITERABLE (parameter_collection));
-					while (gee_iterator_next (parameter_it)) {
+					for (parameter_it = 0; parameter_it < gee_collection_get_size (GEE_COLLECTION (parameter_collection)); parameter_it = parameter_it + 1) {
 						GtkamlImplicitsParameter* parameter;
-						parameter = ((GtkamlImplicitsParameter*) gee_iterator_get (parameter_it));
+						parameter = ((GtkamlImplicitsParameter*) (gee_list_get (GEE_LIST (parameter_collection), parameter_it)));
 						{
 							gint flag_current_matches_modified;
 							/*stderr.printf ("searching for %s =>", parameter.name); */
 							flag_current_matches_modified = current_matches;
 							{
 								GeeList* attr_collection;
-								GeeIterator* attr_it;
+								int attr_it;
 								attr_collection = gtkaml_class_definition_get_attrs (self->priv->class_owning_parameters);
-								attr_it = gee_iterable_iterator (GEE_ITERABLE (attr_collection));
-								while (gee_iterator_next (attr_it)) {
+								for (attr_it = 0; attr_it < gee_collection_get_size (GEE_COLLECTION (attr_collection)); attr_it = attr_it + 1) {
 									GtkamlAttribute* attr;
-									attr = ((GtkamlAttribute*) gee_iterator_get (attr_it));
+									attr = ((GtkamlAttribute*) (gee_list_get (GEE_LIST (attr_collection), attr_it)));
 									{
 										if (_vala_strcmp0 (parameter->name, gtkaml_attribute_get_name (attr)) == 0) {
 											current_matches++;
@@ -171,7 +168,6 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 										(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 									}
 								}
-								(attr_it == NULL ? NULL : (attr_it = (g_object_unref (attr_it), NULL)));
 							}
 							if (flag_current_matches_modified == current_matches) {
 								if (parameter->default_value != NULL) {
@@ -183,7 +179,6 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 							(parameter == NULL ? NULL : (parameter = (g_object_unref (parameter), NULL)));
 						}
 					}
-					(parameter_it == NULL ? NULL : (parameter_it = (g_object_unref (parameter_it), NULL)));
 				}
 				/*stderr.printf (" .. default %s\n", parameter.name);
 				stderr.printf (" .. not found\n");*/
@@ -250,10 +245,9 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 				(current_defaulted_parameters == NULL ? NULL : (current_defaulted_parameters = (g_object_unref (current_defaulted_parameters), NULL)));
 			}
 		}
-		(method_it == NULL ? NULL : (method_it = (g_object_unref (method_it), NULL)));
 	}
 	if (self->priv->max_matches_method == NULL) {
-		gpointer _tmp17;
+		ValaMethod* _tmp17;
 		if (self->priv->min_param_names == NULL) {
 			char* _tmp10;
 			_tmp10 = NULL;
@@ -275,7 +269,7 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 				_tmp13 = NULL;
 				_tmp12 = NULL;
 				_tmp11 = NULL;
-				message = (_tmp13 = g_strconcat (message, (_tmp12 = (g_strconcat ((_tmp11 = ((GtkamlImplicitsParameter*) gee_list_get (self->priv->min_param_names, i)))->name, ", ", NULL))), NULL), (message = (g_free (message), NULL)), _tmp13);
+				message = (_tmp13 = g_strconcat (message, (_tmp12 = (g_strconcat ((_tmp11 = ((GtkamlImplicitsParameter*) (gee_list_get (self->priv->min_param_names, i))))->name, ", ", NULL))), NULL), (message = (g_free (message), NULL)), _tmp13);
 				_tmp12 = (g_free (_tmp12), NULL);
 				(_tmp11 == NULL ? NULL : (_tmp11 = (g_object_unref (_tmp11), NULL)));
 			}
@@ -284,7 +278,7 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 				GtkamlImplicitsParameter* _tmp14;
 				_tmp15 = NULL;
 				_tmp14 = NULL;
-				message = (_tmp15 = g_strconcat (message, ((_tmp14 = ((GtkamlImplicitsParameter*) gee_list_get (self->priv->min_param_names, i)))->name), NULL), (message = (g_free (message), NULL)), _tmp15);
+				message = (_tmp15 = g_strconcat (message, ((_tmp14 = ((GtkamlImplicitsParameter*) (gee_list_get (self->priv->min_param_names, i))))->name), NULL), (message = (g_free (message), NULL)), _tmp15);
 				(_tmp14 == NULL ? NULL : (_tmp14 = (g_object_unref (_tmp14), NULL)));
 			}
 			_tmp16 = NULL;
@@ -292,6 +286,7 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 			_tmp16 = (g_free (_tmp16), NULL);
 			message = (g_free (message), NULL);
 		}
+		_tmp17 = NULL;
 		return (_tmp17 = NULL, (defaulted_parameters == NULL ? NULL : (defaulted_parameters = (g_object_unref (defaulted_parameters), NULL))), _tmp17);
 	}
 	if (self->priv->count_with_max_match > 1) {
@@ -299,12 +294,11 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 	/*Report.warning (class_owning_method.source_reference, "More than one %s matches your definition of %s(%s)\n".printf (wording, class_owning_method.identifier, class_owning_method.base_full_name));*/
 	{
 		GeeList* parameter_collection;
-		GeeIterator* parameter_it;
+		int parameter_it;
 		parameter_collection = self->priv->max_matches_method_defaulted_parameters;
-		parameter_it = gee_iterable_iterator (GEE_ITERABLE (parameter_collection));
-		while (gee_iterator_next (parameter_it)) {
+		for (parameter_it = 0; parameter_it < gee_collection_get_size (GEE_COLLECTION (parameter_collection)); parameter_it = parameter_it + 1) {
 			GtkamlImplicitsParameter* parameter;
-			parameter = ((GtkamlImplicitsParameter*) gee_iterator_get (parameter_it));
+			parameter = ((GtkamlImplicitsParameter*) (gee_list_get (GEE_LIST (parameter_collection), parameter_it)));
 			{
 				/*stderr.printf ("found default value for %s.%s.%s being <%s>\n", class_owning_method.base_full_name, max_matches_method.name, parameter.name, parameter.default_value);*/
 				if (self->priv->_first_parameter != NULL) {
@@ -321,7 +315,6 @@ ValaMethod* gtkaml_method_matcher_determine_matching_method (GtkamlMethodMatcher
 				(parameter == NULL ? NULL : (parameter = (g_object_unref (parameter), NULL)));
 			}
 		}
-		(parameter_it == NULL ? NULL : (parameter_it = (g_object_unref (parameter_it), NULL)));
 	}
 	/*stderr.printf ("selected '%s'\n", max_matches_method.name);*/
 	_tmp20 = NULL;
@@ -338,30 +331,28 @@ void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, Gtk
 	g_return_if_fail (GTKAML_IS_METHOD_MATCHER (self));
 	g_return_if_fail (GTKAML_IS_METHOD (new_method));
 	g_return_if_fail (VALA_IS_METHOD (determined_method));
-	to_remove = GEE_LIST (gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	to_remove = GEE_LIST (gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 	gtkaml_method_set_name (new_method, vala_symbol_get_name (VALA_SYMBOL (determined_method)));
 	if (self->priv->_first_parameter != NULL) {
-		gee_collection_add (GEE_COLLECTION (gtkaml_method_get_parameter_attributes (new_method)), self->priv->_first_parameter);
+		gee_collection_add (GEE_COLLECTION (gtkaml_method_get_parameter_attributes (new_method)), GTKAML_ATTRIBUTE (self->priv->_first_parameter));
 	}
 	/*move the attributes from class definition to add method*/
 	parameters = gtkaml_implicits_store_determine_parameter_names_and_default_values (self->priv->_implicits_store, self->priv->_class_owning_method, determined_method);
 	{
 		GeeList* parameter_collection;
-		GeeIterator* parameter_it;
+		int parameter_it;
 		parameter_collection = parameters;
-		parameter_it = gee_iterable_iterator (GEE_ITERABLE (parameter_collection));
-		while (gee_iterator_next (parameter_it)) {
+		for (parameter_it = 0; parameter_it < gee_collection_get_size (GEE_COLLECTION (parameter_collection)); parameter_it = parameter_it + 1) {
 			GtkamlImplicitsParameter* parameter;
-			parameter = ((GtkamlImplicitsParameter*) gee_iterator_get (parameter_it));
+			parameter = ((GtkamlImplicitsParameter*) (gee_list_get (GEE_LIST (parameter_collection), parameter_it)));
 			{
 				{
 					GeeList* attr_collection;
-					GeeIterator* attr_it;
+					int attr_it;
 					attr_collection = gtkaml_class_definition_get_attrs (self->priv->class_owning_parameters);
-					attr_it = gee_iterable_iterator (GEE_ITERABLE (attr_collection));
-					while (gee_iterator_next (attr_it)) {
+					for (attr_it = 0; attr_it < gee_collection_get_size (GEE_COLLECTION (attr_collection)); attr_it = attr_it + 1) {
 						GtkamlAttribute* attr;
-						attr = ((GtkamlAttribute*) gee_iterator_get (attr_it));
+						attr = ((GtkamlAttribute*) (gee_list_get (GEE_LIST (attr_collection), attr_it)));
 						{
 							if (_vala_strcmp0 (parameter->name, gtkaml_attribute_get_name (attr)) == 0) {
 								gee_collection_add (GEE_COLLECTION (gtkaml_method_get_parameter_attributes (new_method)), attr);
@@ -372,12 +363,10 @@ void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, Gtk
 							(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 						}
 					}
-					(attr_it == NULL ? NULL : (attr_it = (g_object_unref (attr_it), NULL)));
 				}
 				(parameter == NULL ? NULL : (parameter = (g_object_unref (parameter), NULL)));
 			}
 		}
-		(parameter_it == NULL ? NULL : (parameter_it = (g_object_unref (parameter_it), NULL)));
 	}
 	i = 0;
 	if (gee_collection_get_size (GEE_COLLECTION (parameters)) != gee_collection_get_size (GEE_COLLECTION (gtkaml_method_get_parameter_attributes (new_method)))) {
@@ -397,7 +386,7 @@ void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, Gtk
 			_tmp2 = NULL;
 			_tmp1 = NULL;
 			_tmp0 = NULL;
-			message = (_tmp2 = g_strconcat (message, (_tmp1 = (g_strconcat ((_tmp0 = ((GtkamlImplicitsParameter*) gee_list_get (parameters, i)))->name, ", ", NULL))), NULL), (message = (g_free (message), NULL)), _tmp2);
+			message = (_tmp2 = g_strconcat (message, (_tmp1 = (g_strconcat ((_tmp0 = ((GtkamlImplicitsParameter*) (gee_list_get (parameters, i))))->name, ", ", NULL))), NULL), (message = (g_free (message), NULL)), _tmp2);
 			_tmp1 = (g_free (_tmp1), NULL);
 			(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
 		}
@@ -406,7 +395,7 @@ void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, Gtk
 			GtkamlImplicitsParameter* _tmp3;
 			_tmp4 = NULL;
 			_tmp3 = NULL;
-			message = (_tmp4 = g_strconcat (message, ((_tmp3 = ((GtkamlImplicitsParameter*) gee_list_get (parameters, i)))->name), NULL), (message = (g_free (message), NULL)), _tmp4);
+			message = (_tmp4 = g_strconcat (message, ((_tmp3 = ((GtkamlImplicitsParameter*) (gee_list_get (parameters, i))))->name), NULL), (message = (g_free (message), NULL)), _tmp4);
 			(_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL)));
 		}
 		_tmp5 = NULL;
@@ -418,7 +407,7 @@ void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, Gtk
 		return;
 	}
 	/*determine attr.target_types directly from method signature*/
-	method_parameters = vala_method_get_parameters (determined_method);
+	method_parameters = GEE_COLLECTION (vala_method_get_parameters (determined_method));
 	i = 0;
 	{
 		GeeCollection* formal_parameter_collection;
@@ -427,11 +416,11 @@ void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, Gtk
 		formal_parameter_it = gee_iterable_iterator (GEE_ITERABLE (formal_parameter_collection));
 		while (gee_iterator_next (formal_parameter_it)) {
 			ValaFormalParameter* formal_parameter;
-			formal_parameter = ((ValaFormalParameter*) gee_iterator_get (formal_parameter_it));
+			formal_parameter = ((ValaFormalParameter*) (gee_iterator_get (formal_parameter_it)));
 			{
 				if (!vala_formal_parameter_get_ellipsis (formal_parameter)) {
 					GtkamlAttribute* attr;
-					attr = ((GtkamlAttribute*) gee_list_get (gtkaml_method_get_parameter_attributes (new_method), i));
+					attr = ((GtkamlAttribute*) (gee_list_get (gtkaml_method_get_parameter_attributes (new_method), i)));
 					gtkaml_attribute_set_target_type (attr, VALA_SYMBOL (formal_parameter));
 					i++;
 					(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
@@ -443,18 +432,16 @@ void gtkaml_method_matcher_set_method_parameters (GtkamlMethodMatcher* self, Gtk
 	}
 	{
 		GeeList* attr_collection;
-		GeeIterator* attr_it;
+		int attr_it;
 		attr_collection = to_remove;
-		attr_it = gee_iterable_iterator (GEE_ITERABLE (attr_collection));
-		while (gee_iterator_next (attr_it)) {
+		for (attr_it = 0; attr_it < gee_collection_get_size (GEE_COLLECTION (attr_collection)); attr_it = attr_it + 1) {
 			GtkamlAttribute* attr;
-			attr = ((GtkamlAttribute*) gee_iterator_get (attr_it));
+			attr = ((GtkamlAttribute*) (gee_list_get (GEE_LIST (attr_collection), attr_it)));
 			{
 				gee_collection_remove (GEE_COLLECTION (gtkaml_class_definition_get_attrs (self->priv->class_owning_parameters)), attr);
 				(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 			}
 		}
-		(attr_it == NULL ? NULL : (attr_it = (g_object_unref (attr_it), NULL)));
 	}
 	(to_remove == NULL ? NULL : (to_remove = (g_object_unref (to_remove), NULL)));
 	(parameters == NULL ? NULL : (parameters = (g_object_unref (parameters), NULL)));
@@ -478,7 +465,7 @@ static void gtkaml_method_matcher_set_class_owning_method (GtkamlMethodMatcher*
 }
 
 
-char* gtkaml_method_matcher_get_wording (GtkamlMethodMatcher* self) {
+const char* gtkaml_method_matcher_get_wording (GtkamlMethodMatcher* self) {
 	g_return_val_if_fail (GTKAML_IS_METHOD_MATCHER (self), NULL);
 	return self->priv->_wording;
 }
@@ -614,9 +601,9 @@ static void gtkaml_method_matcher_class_init (GtkamlMethodMatcherClass * klass)
 }
 
 
-static void gtkaml_method_matcher_init (GtkamlMethodMatcher * self) {
+static void gtkaml_method_matcher_instance_init (GtkamlMethodMatcher * self) {
 	self->priv = GTKAML_METHOD_MATCHER_GET_PRIVATE (self);
-	self->priv->methods = GEE_LIST (gee_array_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->methods = GEE_LIST (gee_array_list_new (VALA_TYPE_METHOD, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 	self->priv->min_params = 999;
 	self->priv->min_param_names = NULL;
 	self->priv->max_matches = -1;
@@ -646,7 +633,7 @@ static void gtkaml_method_matcher_dispose (GObject * obj) {
 GType gtkaml_method_matcher_get_type (void) {
 	static GType gtkaml_method_matcher_type_id = 0;
 	if (G_UNLIKELY (gtkaml_method_matcher_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GtkamlMethodMatcherClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_method_matcher_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlMethodMatcher), 0, (GInstanceInitFunc) gtkaml_method_matcher_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GtkamlMethodMatcherClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_method_matcher_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlMethodMatcher), 0, (GInstanceInitFunc) gtkaml_method_matcher_instance_init };
 		gtkaml_method_matcher_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlMethodMatcher", &g_define_type_info, 0);
 	}
 	return gtkaml_method_matcher_type_id;
