@@ -69,8 +69,8 @@ void gtkaml_parser_parse (GtkamlParser* self, ValaCodeContext* context, char** i
 	if (implicits_directories != NULL) {
 		{
 			char** implicits_dirs_collection;
-			char** implicits_dirs_it;
 			int implicits_dirs_collection_length1;
+			char** implicits_dirs_it;
 			implicits_dirs_collection = implicits_directories;
 			implicits_dirs_collection_length1 = -1;
 			for (implicits_dirs_it = implicits_dirs_collection; *implicits_dirs_it != NULL; implicits_dirs_it = implicits_dirs_it + 1) {
@@ -87,8 +87,8 @@ void gtkaml_parser_parse (GtkamlParser* self, ValaCodeContext* context, char** i
 	}
 	{
 		char** datadir_collection;
-		char** datadir_it;
 		int datadir_collection_length1;
+		char** datadir_it;
 		datadir_collection = g_get_system_data_dirs ();
 		datadir_collection_length1 = -1;
 		for (datadir_it = datadir_collection; *datadir_it != NULL; datadir_it = datadir_it + 1) {
@@ -176,7 +176,7 @@ static void gtkaml_parser_real_parse_gtkaml_file (GtkamlParser* self, ValaSource
 				char* vala_filename;
 				_tmp0 = NULL;
 				_tmp1 = NULL;
-				vala_filename = (_tmp1 = g_strconcat ((_tmp0 = g_strndup (vala_source_file_get_filename (gtkaml_source_file), ((gulong) g_utf8_strlen (vala_source_file_get_filename (gtkaml_source_file), -1) - g_utf8_strlen (".gtkaml", -1)))), ".vala", NULL), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+				vala_filename = (_tmp1 = g_strconcat ((_tmp0 = g_strndup (vala_source_file_get_filename (gtkaml_source_file), ((gulong) (g_utf8_strlen (vala_source_file_get_filename (gtkaml_source_file), -1) - g_utf8_strlen (".gtkaml", -1))))), ".vala", NULL), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 				g_file_set_contents (vala_filename, vala_contents, -1, &inner_error);
 				if (inner_error != NULL) {
 					if (inner_error->domain == G_FILE_ERROR) {
@@ -234,7 +234,7 @@ static void gtkaml_parser_class_init (GtkamlParserClass * klass) {
 }
 
 
-static void gtkaml_parser_init (GtkamlParser * self) {
+static void gtkaml_parser_instance_init (GtkamlParser * self) {
 	self->priv = GTKAML_PARSER_GET_PRIVATE (self);
 	self->priv->implicits_store = gtkaml_implicits_store_new ();
 }
@@ -253,7 +253,7 @@ static void gtkaml_parser_dispose (GObject * obj) {
 GType gtkaml_parser_get_type (void) {
 	static GType gtkaml_parser_type_id = 0;
 	if (G_UNLIKELY (gtkaml_parser_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GtkamlParserClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_parser_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlParser), 0, (GInstanceInitFunc) gtkaml_parser_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GtkamlParserClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_parser_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlParser), 0, (GInstanceInitFunc) gtkaml_parser_instance_init };
 		gtkaml_parser_type_id = g_type_register_static (VALA_TYPE_PARSER, "GtkamlParser", &g_define_type_info, 0);
 	}
 	return gtkaml_parser_type_id;
