@@ -60,11 +60,11 @@ GtkamlReferenceClassDefinition* gtkaml_reference_class_definition_new (ValaSourc
 	gtkaml_class_definition_set_definition_scope (GTKAML_CLASS_DEFINITION (self), 0);
 	gtkaml_class_definition_set_parent_container (GTKAML_CLASS_DEFINITION (self), parent_container);
 	_tmp0 = NULL;
-	gtkaml_class_definition_set_attrs (GTKAML_CLASS_DEFINITION (self), GEE_LIST ((_tmp0 = gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal))));
+	gtkaml_class_definition_set_attrs (GTKAML_CLASS_DEFINITION (self), GEE_LIST ((_tmp0 = gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal))));
 	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
 	gtkaml_class_definition_set_construct_method (GTKAML_CLASS_DEFINITION (self), NULL);
 	_tmp1 = NULL;
-	gtkaml_class_definition_set_children (GTKAML_CLASS_DEFINITION (self), GEE_LIST ((_tmp1 = gee_array_list_new (GTKAML_TYPE_CLASS_DEFINITION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal))));
+	gtkaml_class_definition_set_children (GTKAML_CLASS_DEFINITION (self), GEE_LIST ((_tmp1 = gee_array_list_new (GTKAML_TYPE_CLASS_DEFINITION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal))));
 	(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
 	gtkaml_class_definition_set_construct_code (GTKAML_CLASS_DEFINITION (self), NULL);
 	gtkaml_class_definition_set_preconstruct_code (GTKAML_CLASS_DEFINITION (self), NULL);
@@ -115,7 +115,7 @@ static void gtkaml_reference_class_definition_class_init (GtkamlReferenceClassDe
 }
 
 
-static void gtkaml_reference_class_definition_init (GtkamlReferenceClassDefinition * self) {
+static void gtkaml_reference_class_definition_instance_init (GtkamlReferenceClassDefinition * self) {
 	self->priv = GTKAML_REFERENCE_CLASS_DEFINITION_GET_PRIVATE (self);
 }
 
@@ -130,7 +130,7 @@ static void gtkaml_reference_class_definition_dispose (GObject * obj) {
 GType gtkaml_reference_class_definition_get_type (void) {
 	static GType gtkaml_reference_class_definition_type_id = 0;
 	if (G_UNLIKELY (gtkaml_reference_class_definition_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GtkamlReferenceClassDefinitionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_reference_class_definition_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlReferenceClassDefinition), 0, (GInstanceInitFunc) gtkaml_reference_class_definition_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GtkamlReferenceClassDefinitionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_reference_class_definition_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlReferenceClassDefinition), 0, (GInstanceInitFunc) gtkaml_reference_class_definition_instance_init };
 		gtkaml_reference_class_definition_type_id = g_type_register_static (GTKAML_TYPE_CLASS_DEFINITION, "GtkamlReferenceClassDefinition", &g_define_type_info, 0);
 	}
 	return gtkaml_reference_class_definition_type_id;
