@@ -69,18 +69,18 @@ GtkamlRootClassDefinition* gtkaml_root_class_definition_new (ValaSourceReference
 	gtkaml_class_definition_set_definition_scope (GTKAML_CLASS_DEFINITION (self), definition_scope);
 	gtkaml_class_definition_set_parent_container (GTKAML_CLASS_DEFINITION (self), parent_container);
 	_tmp0 = NULL;
-	gtkaml_class_definition_set_attrs (GTKAML_CLASS_DEFINITION (self), GEE_LIST ((_tmp0 = gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal))));
+	gtkaml_class_definition_set_attrs (GTKAML_CLASS_DEFINITION (self), GEE_LIST ((_tmp0 = gee_array_list_new (GTKAML_TYPE_ATTRIBUTE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal))));
 	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
 	gtkaml_class_definition_set_construct_method (GTKAML_CLASS_DEFINITION (self), NULL);
 	_tmp1 = NULL;
-	gtkaml_class_definition_set_children (GTKAML_CLASS_DEFINITION (self), GEE_LIST ((_tmp1 = gee_array_list_new (GTKAML_TYPE_CLASS_DEFINITION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal))));
+	gtkaml_class_definition_set_children (GTKAML_CLASS_DEFINITION (self), GEE_LIST ((_tmp1 = gee_array_list_new (GTKAML_TYPE_CLASS_DEFINITION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal))));
 	(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
 	gtkaml_class_definition_set_construct_code (GTKAML_CLASS_DEFINITION (self), NULL);
 	gtkaml_class_definition_set_preconstruct_code (GTKAML_CLASS_DEFINITION (self), NULL);
 	gtkaml_root_class_definition_set_target_name (self, NULL);
 	gtkaml_root_class_definition_set_target_namespace (self, NULL);
 	_tmp2 = NULL;
-	gtkaml_root_class_definition_set_code (self, GEE_LIST ((_tmp2 = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, g_direct_equal))));
+	gtkaml_root_class_definition_set_code (self, GEE_LIST ((_tmp2 = gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_direct_equal))));
 	(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
 	gtkaml_root_class_definition_set_implements (self, NULL);
 	gtkaml_root_class_definition_set_original_first_code_line (self, -1);
@@ -104,7 +104,7 @@ void gtkaml_root_class_definition_set_prefixes_namespaces (GtkamlRootClassDefini
 }
 
 
-char* gtkaml_root_class_definition_get_target_name (GtkamlRootClassDefinition* self) {
+const char* gtkaml_root_class_definition_get_target_name (GtkamlRootClassDefinition* self) {
 	g_return_val_if_fail (GTKAML_IS_ROOT_CLASS_DEFINITION (self), NULL);
 	return self->priv->_target_name;
 }
@@ -120,7 +120,7 @@ void gtkaml_root_class_definition_set_target_name (GtkamlRootClassDefinition* se
 }
 
 
-char* gtkaml_root_class_definition_get_target_namespace (GtkamlRootClassDefinition* self) {
+const char* gtkaml_root_class_definition_get_target_namespace (GtkamlRootClassDefinition* self) {
 	g_return_val_if_fail (GTKAML_IS_ROOT_CLASS_DEFINITION (self), NULL);
 	return self->priv->_target_namespace;
 }
@@ -164,7 +164,7 @@ void gtkaml_root_class_definition_set_original_first_code_line (GtkamlRootClassD
 }
 
 
-char* gtkaml_root_class_definition_get_implements (GtkamlRootClassDefinition* self) {
+const char* gtkaml_root_class_definition_get_implements (GtkamlRootClassDefinition* self) {
 	g_return_val_if_fail (GTKAML_IS_ROOT_CLASS_DEFINITION (self), NULL);
 	return self->priv->_implements;
 }
@@ -253,7 +253,7 @@ static void gtkaml_root_class_definition_class_init (GtkamlRootClassDefinitionCl
 }
 
 
-static void gtkaml_root_class_definition_init (GtkamlRootClassDefinition * self) {
+static void gtkaml_root_class_definition_instance_init (GtkamlRootClassDefinition * self) {
 	self->priv = GTKAML_ROOT_CLASS_DEFINITION_GET_PRIVATE (self);
 }
 
@@ -273,7 +273,7 @@ static void gtkaml_root_class_definition_dispose (GObject * obj) {
 GType gtkaml_root_class_definition_get_type (void) {
 	static GType gtkaml_root_class_definition_type_id = 0;
 	if (G_UNLIKELY (gtkaml_root_class_definition_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GtkamlRootClassDefinitionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_root_class_definition_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlRootClassDefinition), 0, (GInstanceInitFunc) gtkaml_root_class_definition_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GtkamlRootClassDefinitionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_root_class_definition_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlRootClassDefinition), 0, (GInstanceInitFunc) gtkaml_root_class_definition_instance_init };
 		gtkaml_root_class_definition_type_id = g_type_register_static (GTKAML_TYPE_CLASS_DEFINITION, "GtkamlRootClassDefinition", &g_define_type_info, 0);
 	}
 	return gtkaml_root_class_definition_type_id;
