@@ -114,19 +114,20 @@ static GtkamlRootClassDefinition* gtkaml_sax_parser_real_parse (GtkamlSAXParser*
 	char* contents;
 	gulong length;
 	GtkamlState* initial_state;
-	GtkamlRootClassDefinition* _tmp2;
 	GtkamlRootClassDefinition* _tmp3;
+	GtkamlRootClassDefinition* _tmp4;
 	g_return_val_if_fail (GTKAML_IS_SAX_PARSER (self), NULL);
 	inner_error = NULL;
 	contents = NULL;
 	length = 0UL;
 	{
+		char* _tmp2;
 		gboolean _tmp1;
 		char* _tmp0;
+		_tmp2 = NULL;
 		_tmp0 = NULL;
 		_tmp1 = g_file_get_contents (vala_source_file_get_filename (self->priv->_source_file), &_tmp0, &length, &inner_error);
-		(contents = (g_free (contents), NULL));
-		contents = _tmp0;
+		contents = (_tmp2 = _tmp0, (contents = (g_free (contents), NULL)), _tmp2);
 		_tmp1;
 		if (inner_error != NULL) {
 			if (inner_error->domain == G_FILE_ERROR) {
@@ -151,9 +152,9 @@ static GtkamlRootClassDefinition* gtkaml_sax_parser_real_parse (GtkamlSAXParser*
 	initial_state = gtkaml_state_new (GTKAML_STATE_ID_SAX_PARSER_INITIAL_STATE, NULL, NULL, NULL);
 	gtkaml_state_stack_push (self->priv->_states, initial_state);
 	gtkaml_sax_parser_start_parsing (self, contents, length);
-	_tmp2 = NULL;
 	_tmp3 = NULL;
-	return (_tmp3 = (_tmp2 = self->priv->_root_class_definition, (_tmp2 == NULL ? NULL : g_object_ref (_tmp2))), (contents = (g_free (contents), NULL)), (initial_state == NULL ? NULL : (initial_state = (g_object_unref (initial_state), NULL))), _tmp3);
+	_tmp4 = NULL;
+	return (_tmp4 = (_tmp3 = self->priv->_root_class_definition, (_tmp3 == NULL ? NULL : g_object_ref (_tmp3))), (contents = (g_free (contents), NULL)), (initial_state == NULL ? NULL : (initial_state = (g_object_unref (initial_state), NULL))), _tmp4);
 }
 
 
@@ -187,12 +188,11 @@ void gtkaml_sax_parser_start_element (GtkamlSAXParser* self, const char* localna
 			nss = gtkaml_sax_parser_parse_namespaces (self, namespaces, nb_namespaces);
 			{
 				GeeList* ns_collection;
-				GeeIterator* ns_it;
+				int ns_it;
 				ns_collection = nss;
-				ns_it = gee_iterable_iterator (GEE_ITERABLE (ns_collection));
-				while (gee_iterator_next (ns_it)) {
+				for (ns_it = 0; ns_it < gee_collection_get_size (GEE_COLLECTION (ns_collection)); ns_it = ns_it + 1) {
 					XmlNamespace* ns;
-					ns = ((XmlNamespace*) gee_iterator_get (ns_it));
+					ns = ((XmlNamespace*) (gee_list_get (GEE_LIST (ns_collection), ns_it)));
 					{
 						if (NULL == ns->prefix || NULL != ns->prefix && _vala_strcmp0 (ns->prefix, self->gtkaml_prefix) != 0) {
 							char** _tmp0;
@@ -204,17 +204,18 @@ void gtkaml_sax_parser_start_element (GtkamlSAXParser* self, const char* localna
 							namespace_reference = vala_namespace_reference_new (uri_definition[0], source_reference);
 							vala_source_file_add_using_directive (self->priv->_source_file, namespace_reference);
 							if (NULL == ns->prefix) {
+								/*stderr.printf ("adding '%s':'%s' to prefixes_namespaces map\n", "", uri_definition[0]);*/
 								gee_map_set (self->priv->_prefixes_namespaces, "", uri_definition[0]);
 							} else {
+								/*stderr.printf ("adding '%s':'%s' to prefixes_namespaces map\n", ns.prefix, uri_definition[0]);*/
 								gee_map_set (self->priv->_prefixes_namespaces, ns->prefix, uri_definition[0]);
 							}
-							uri_definition = (_vala_array_free (uri_definition, uri_definition_length1, ((GDestroyNotify) g_free)), NULL);
+							uri_definition = (_vala_array_free (uri_definition, uri_definition_length1, ((GDestroyNotify) (g_free))), NULL);
 							(namespace_reference == NULL ? NULL : (namespace_reference = (g_object_unref (namespace_reference), NULL)));
 						}
 						(ns == NULL ? NULL : (ns = (g_object_unref (ns), NULL)));
 					}
 				}
-				(ns_it == NULL ? NULL : (ns_it = (g_object_unref (ns_it), NULL)));
 			}
 			_tmp1 = NULL;
 			_tmp2 = NULL;
@@ -395,7 +396,7 @@ void gtkaml_sax_parser_characters (GtkamlSAXParser* self, const char* data, gint
 	g_return_if_fail (GTKAML_IS_SAX_PARSER (self));
 	g_return_if_fail (data != NULL);
 	state = gtkaml_state_stack_peek (self->priv->_states, 0);
-	value = g_strndup (data, ((gulong) len));
+	value = g_strndup (data, ((gulong) (len)));
 	_tmp0 = NULL;
 	stripped_value = (_tmp0 = value, (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
 	g_strstrip (stripped_value);
@@ -434,18 +435,18 @@ void gtkaml_sax_parser_cdata_block (GtkamlSAXParser* self, const char* cdata, gi
 			char* _tmp2;
 			_tmp1 = NULL;
 			_tmp0 = NULL;
-			root_class = (_tmp1 = (_tmp0 = gtkaml_state_get_class_definition (state), (GTKAML_IS_ROOT_CLASS_DEFINITION (_tmp0) ? ((GtkamlRootClassDefinition*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+			root_class = (_tmp1 = (_tmp0 = gtkaml_state_get_class_definition (state), (GTKAML_IS_ROOT_CLASS_DEFINITION (_tmp0) ? ((GtkamlRootClassDefinition*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
 			if (gtkaml_root_class_definition_get_original_first_code_line (root_class) < 0) {
 				gtkaml_root_class_definition_set_original_first_code_line (root_class, gtkaml_sax_parser_line_number (self));
 			}
 			_tmp2 = NULL;
-			gee_collection_add (GEE_COLLECTION (gtkaml_root_class_definition_get_code (root_class)), (_tmp2 = g_strndup (cdata, ((gulong) len))));
+			gee_collection_add (GEE_COLLECTION (gtkaml_root_class_definition_get_code (root_class)), (_tmp2 = g_strndup (cdata, ((gulong) (len)))));
 			_tmp2 = (g_free (_tmp2), NULL);
 			(root_class == NULL ? NULL : (root_class = (g_object_unref (root_class), NULL)));
 		} else {
 			char* _tmp3;
 			_tmp3 = NULL;
-			gtkaml_sax_parser_parse_attribute_content_as_text (self, state, (_tmp3 = g_strndup (cdata, ((gulong) len))));
+			gtkaml_sax_parser_parse_attribute_content_as_text (self, state, (_tmp3 = g_strndup (cdata, ((gulong) (len)))));
 			_tmp3 = (g_free (_tmp3), NULL);
 		}
 		(previous_state == NULL ? NULL : (previous_state = (g_object_unref (previous_state), NULL)));
@@ -512,7 +513,7 @@ static void gtkaml_sax_parser_parse_attribute_content_as_text (GtkamlSAXParser*
 						_tmp12 = NULL;
 						_tmp10 = NULL;
 						_tmp11 = NULL;
-						gtkaml_simple_attribute_set_value (((_tmp11 = gtkaml_state_get_attribute (state), (GTKAML_IS_SIMPLE_ATTRIBUTE (_tmp11) ? ((GtkamlSimpleAttribute*) _tmp11) : NULL))), (_tmp13 = g_strconcat (gtkaml_simple_attribute_get_value (((_tmp11 = gtkaml_state_get_attribute (state), (GTKAML_IS_SIMPLE_ATTRIBUTE (_tmp11) ? ((GtkamlSimpleAttribute*) _tmp11) : NULL)))), (_tmp12 = (g_strconcat ("\n", content, NULL))), NULL)));
+						gtkaml_simple_attribute_set_value (((_tmp11 = gtkaml_state_get_attribute (state), (GTKAML_IS_SIMPLE_ATTRIBUTE (_tmp11) ? ((GtkamlSimpleAttribute*) (_tmp11)) : NULL))), (_tmp13 = g_strconcat (gtkaml_simple_attribute_get_value (((_tmp11 = gtkaml_state_get_attribute (state), (GTKAML_IS_SIMPLE_ATTRIBUTE (_tmp11) ? ((GtkamlSimpleAttribute*) (_tmp11)) : NULL)))), (_tmp12 = (g_strconcat ("\n", content, NULL))), NULL)));
 						_tmp13 = (g_free (_tmp13), NULL);
 						_tmp12 = (g_free (_tmp12), NULL);
 					} else {
@@ -543,9 +544,9 @@ static void gtkaml_sax_parser_parse_attribute_content_as_text (GtkamlSAXParser*
 static char* gtkaml_sax_parser_prefix_to_namespace (GtkamlSAXParser* self, const char* prefix) {
 	g_return_val_if_fail (GTKAML_IS_SAX_PARSER (self), NULL);
 	if (prefix == NULL) {
-		return ((char*) gee_map_get (self->priv->_prefixes_namespaces, ""));
+		return ((char*) (gee_map_get (self->priv->_prefixes_namespaces, "")));
 	}
-	return ((char*) gee_map_get (self->priv->_prefixes_namespaces, prefix));
+	return ((char*) (gee_map_get (self->priv->_prefixes_namespaces, prefix)));
 }
 
 
@@ -559,13 +560,12 @@ static ValaClass* gtkaml_sax_parser_lookup_class (GtkamlSAXParser* self, const c
 	g_return_val_if_fail (GTKAML_IS_SAX_PARSER (self), NULL);
 	g_return_val_if_fail (name != NULL, NULL);
 	{
-		GeeCollection* ns_collection;
-		GeeIterator* ns_it;
+		GeeList* ns_collection;
+		int ns_it;
 		ns_collection = vala_namespace_get_namespaces (vala_code_context_get_root (self->priv->_context));
-		ns_it = gee_iterable_iterator (GEE_ITERABLE (ns_collection));
-		while (gee_iterator_next (ns_it)) {
+		for (ns_it = 0; ns_it < gee_collection_get_size (GEE_COLLECTION (ns_collection)); ns_it = ns_it + 1) {
 			ValaNamespace* ns;
-			ns = ((ValaNamespace*) gee_iterator_get (ns_it));
+			ns = ((ValaNamespace*) (gee_list_get (GEE_LIST (ns_collection), ns_it)));
 			{
 				if (_vala_strcmp0 (xmlNamespace, vala_symbol_get_name (VALA_SYMBOL (ns))) == 0) {
 					ValaSymbol* s;
@@ -577,7 +577,7 @@ static ValaClass* gtkaml_sax_parser_lookup_class (GtkamlSAXParser* self, const c
 						_tmp1 = NULL;
 						_tmp0 = NULL;
 						_tmp2 = NULL;
-						return (_tmp2 = (_tmp1 = ((_tmp0 = s, (VALA_IS_CLASS (_tmp0) ? ((ValaClass*) _tmp0) : NULL))), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (s == NULL ? NULL : (s = (g_object_unref (s), NULL))), (ns == NULL ? NULL : (ns = (g_object_unref (ns), NULL))), (ns_collection == NULL ? NULL : (ns_collection = (g_object_unref (ns_collection), NULL))), (ns_it == NULL ? NULL : (ns_it = (g_object_unref (ns_it), NULL))), _tmp2);
+						return (_tmp2 = (_tmp1 = ((_tmp0 = s, (VALA_IS_CLASS (_tmp0) ? ((ValaClass*) (_tmp0)) : NULL))), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (s == NULL ? NULL : (s = (g_object_unref (s), NULL))), (ns == NULL ? NULL : (ns = (g_object_unref (ns), NULL))), (ns_collection == NULL ? NULL : (ns_collection = (g_object_unref (ns_collection), NULL))), _tmp2);
 					}
 					(s == NULL ? NULL : (s = (g_object_unref (s), NULL)));
 				}
@@ -585,7 +585,6 @@ static ValaClass* gtkaml_sax_parser_lookup_class (GtkamlSAXParser* self, const c
 			}
 		}
 		(ns_collection == NULL ? NULL : (ns_collection = (g_object_unref (ns_collection), NULL)));
-		(ns_it == NULL ? NULL : (ns_it = (g_object_unref (ns_it), NULL)));
 	}
 	return NULL;
 }
@@ -602,7 +601,7 @@ static char* gtkaml_sax_parser_strip_attribute_hyphens (GtkamlSAXParser* self, c
 	_tmp0 = NULL;
 	tokens = (_tmp0 = g_strsplit (attrname, "-", 0), tokens_length1 = -1, _tmp0);
 	_tmp1 = NULL;
-	return (_tmp1 = g_strjoinv ("_", tokens), (tokens = (_vala_array_free (tokens, tokens_length1, ((GDestroyNotify) g_free)), NULL)), _tmp1);
+	return (_tmp1 = g_strjoinv ("_", tokens), (tokens = (_vala_array_free (tokens, tokens_length1, ((GDestroyNotify) (g_free))), NULL)), _tmp1);
 }
 
 
@@ -621,12 +620,11 @@ GtkamlRootClassDefinition* gtkaml_sax_parser_get_root_definition (GtkamlSAXParse
 	gtkaml_root_class_definition_set_prefixes_namespaces (root_class_definition, self->priv->_prefixes_namespaces);
 	{
 		GeeList* attr_collection;
-		GeeIterator* attr_it;
+		int attr_it;
 		attr_collection = attrs;
-		attr_it = gee_iterable_iterator (GEE_ITERABLE (attr_collection));
-		while (gee_iterator_next (attr_it)) {
+		for (attr_it = 0; attr_it < gee_collection_get_size (GEE_COLLECTION (attr_collection)); attr_it = attr_it + 1) {
 			GtkamlXmlAttribute* attr;
-			attr = ((GtkamlXmlAttribute*) gee_iterator_get (attr_it));
+			attr = ((GtkamlXmlAttribute*) (gee_list_get (GEE_LIST (attr_collection), attr_it)));
 			{
 				if (attr->prefix != NULL) {
 					if (_vala_strcmp0 (attr->prefix, self->gtkaml_prefix) == 0) {
@@ -708,7 +706,7 @@ GtkamlRootClassDefinition* gtkaml_sax_parser_get_root_definition (GtkamlSAXParse
 							_tmp9 = NULL;
 							gtkaml_root_class_definition_set_implements (root_class_definition, (_tmp9 = g_strjoinv (", ", implementsv)));
 							_tmp9 = (g_free (_tmp9), NULL);
-							implementsv = (_vala_array_free (implementsv, implementsv_length1, ((GDestroyNotify) g_free)), NULL);
+							implementsv = (_vala_array_free (implementsv, implementsv_length1, ((GDestroyNotify) (g_free))), NULL);
 							break;
 						} while (0); else
 						do {
@@ -744,7 +742,6 @@ GtkamlRootClassDefinition* gtkaml_sax_parser_get_root_definition (GtkamlSAXParse
 				(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 			}
 		}
-		(attr_it == NULL ? NULL : (attr_it = (g_object_unref (attr_it), NULL)));
 	}
 	if (gtkaml_root_class_definition_get_target_name (root_class_definition) == NULL) {
 		char* _tmp19;
@@ -782,12 +779,11 @@ GtkamlClassDefinition* gtkaml_sax_parser_get_child_for_container (GtkamlSAXParse
 	parent_container = (_tmp0 = container_definition, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 	{
 		GeeList* attr_collection;
-		GeeIterator* attr_it;
+		int attr_it;
 		attr_collection = attrs;
-		attr_it = gee_iterable_iterator (GEE_ITERABLE (attr_collection));
-		while (gee_iterator_next (attr_it)) {
+		for (attr_it = 0; attr_it < gee_collection_get_size (GEE_COLLECTION (attr_collection)); attr_it = attr_it + 1) {
 			GtkamlXmlAttribute* attr;
-			attr = ((GtkamlXmlAttribute*) gee_iterator_get (attr_it));
+			attr = ((GtkamlXmlAttribute*) (gee_list_get (GEE_LIST (attr_collection), attr_it)));
 			{
 				if (attr->prefix != NULL && _vala_strcmp0 (attr->prefix, self->gtkaml_prefix) == 0) {
 					if ((_vala_strcmp0 (attr->localname, "public") == 0 || _vala_strcmp0 (attr->localname, "private") == 0)) {
@@ -876,7 +872,6 @@ GtkamlClassDefinition* gtkaml_sax_parser_get_child_for_container (GtkamlSAXParse
 				(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 			}
 		}
-		(attr_it == NULL ? NULL : (attr_it = (g_object_unref (attr_it), NULL)));
 	}
 	if (identifier != NULL && reference != NULL) {
 		ValaSourceReference* _tmp17;
@@ -900,7 +895,7 @@ GtkamlClassDefinition* gtkaml_sax_parser_get_child_for_container (GtkamlSAXParse
 			_tmp18 = NULL;
 			identifier = (_tmp18 = g_utf8_strdown (vala_symbol_get_name (VALA_SYMBOL (clazz)), g_utf8_strlen (vala_symbol_get_name (VALA_SYMBOL (clazz)), -1)), (identifier = (g_free (identifier), NULL)), _tmp18);
 			if (gee_map_contains (self->priv->generated_identifiers_counter, identifier)) {
-				counter = GPOINTER_TO_INT (gee_map_get (self->priv->generated_identifiers_counter, identifier));
+				counter = GPOINTER_TO_INT (GPOINTER_TO_INT (gee_map_get (self->priv->generated_identifiers_counter, identifier)));
 			}
 			_tmp19 = NULL;
 			identifier = (_tmp19 = g_strdup_printf ("_%s%d", identifier, counter), (identifier = (g_free (identifier), NULL)), _tmp19);
@@ -946,8 +941,8 @@ GtkamlClassDefinition* gtkaml_sax_parser_get_child_for_container (GtkamlSAXParse
 				char* _tmp29;
 				_tmp30 = NULL;
 				_tmp29 = NULL;
-				gtkaml_class_definition_set_identifier (class_definition, (_tmp30 = g_utf8_offset_to_pointer (reference_stripped, ((glong) 1)), g_strndup (_tmp30, g_utf8_offset_to_pointer (_tmp30, g_utf8_strlen (reference_stripped, -1) - 2) - _tmp30)));
-				_tmp29 = (g_free (_tmp29), NULL);
+				gtkaml_class_definition_set_identifier (class_definition, (_tmp30 = (_tmp29 = g_utf8_offset_to_pointer (reference_stripped, ((glong) (1))), g_strndup (_tmp29, g_utf8_offset_to_pointer (_tmp29, g_utf8_strlen (reference_stripped, -1) - 2) - _tmp29))));
+				_tmp30 = (g_free (_tmp30), NULL);
 			} else {
 				ValaSourceReference* _tmp31;
 				_tmp31 = NULL;
@@ -967,12 +962,11 @@ GtkamlClassDefinition* gtkaml_sax_parser_get_child_for_container (GtkamlSAXParse
 	}
 	{
 		GeeList* attr_collection;
-		GeeIterator* attr_it;
+		int attr_it;
 		attr_collection = attrs;
-		attr_it = gee_iterable_iterator (GEE_ITERABLE (attr_collection));
-		while (gee_iterator_next (attr_it)) {
+		for (attr_it = 0; attr_it < gee_collection_get_size (GEE_COLLECTION (attr_collection)); attr_it = attr_it + 1) {
 			GtkamlXmlAttribute* attr;
-			attr = ((GtkamlXmlAttribute*) gee_iterator_get (attr_it));
+			attr = ((GtkamlXmlAttribute*) (gee_list_get (GEE_LIST (attr_collection), attr_it)));
 			{
 				if (attr->prefix == NULL) {
 					char* _tmp33;
@@ -987,7 +981,6 @@ GtkamlClassDefinition* gtkaml_sax_parser_get_child_for_container (GtkamlSAXParse
 				(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 			}
 		}
-		(attr_it == NULL ? NULL : (attr_it = (g_object_unref (attr_it), NULL)));
 	}
 	_tmp35 = NULL;
 	return (_tmp35 = class_definition, (identifier = (g_free (identifier), NULL)), (reference = (g_free (reference), NULL)), (construct_code = (g_free (construct_code), NULL)), (preconstruct_code = (g_free (preconstruct_code), NULL)), (parent_container == NULL ? NULL : (parent_container = (g_object_unref (parent_container), NULL))), _tmp35);
@@ -998,11 +991,11 @@ static GeeList* gtkaml_sax_parser_parse_attributes (GtkamlSAXParser* self, char*
 	gint walker;
 	char* end;
 	GeeArrayList* attribute_list;
-	GeeArrayList* _tmp11;
+	GeeList* _tmp11;
 	g_return_val_if_fail (GTKAML_IS_SAX_PARSER (self), NULL);
 	walker = 0;
 	end = NULL;
-	attribute_list = gee_array_list_new (GTKAML_TYPE_XML_ATTRIBUTE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal);
+	attribute_list = gee_array_list_new (GTKAML_TYPE_XML_ATTRIBUTE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal);
 	{
 		gint i;
 		i = 0;
@@ -1036,14 +1029,14 @@ static GeeList* gtkaml_sax_parser_parse_attributes (GtkamlSAXParser* self, char*
 			_tmp8 = NULL;
 			end = (_tmp9 = (_tmp8 = attributes[walker + 4], (_tmp8 == NULL ? NULL : g_strdup (_tmp8))), (end = (g_free (end), NULL)), _tmp9);
 			_tmp10 = NULL;
-			attr->value = (_tmp10 = g_strndup (attr->value, ((gulong) g_utf8_strlen (attr->value, -1) - g_utf8_strlen (end, -1))), (attr->value = (g_free (attr->value), NULL)), _tmp10);
+			attr->value = (_tmp10 = g_strndup (attr->value, ((gulong) (g_utf8_strlen (attr->value, -1) - g_utf8_strlen (end, -1)))), (attr->value = (g_free (attr->value), NULL)), _tmp10);
 			gee_collection_add (GEE_COLLECTION (attribute_list), attr);
 			walker = walker + (5);
 			(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
 		}
 	}
 	_tmp11 = NULL;
-	return GEE_LIST ((_tmp11 = attribute_list, (end = (g_free (end), NULL)), _tmp11));
+	return (_tmp11 = GEE_LIST (attribute_list), (end = (g_free (end), NULL)), _tmp11);
 }
 
 
@@ -1052,7 +1045,7 @@ static GeeList* gtkaml_sax_parser_parse_namespaces (GtkamlSAXParser* self, char*
 	GeeArrayList* namespace_list;
 	g_return_val_if_fail (GTKAML_IS_SAX_PARSER (self), NULL);
 	walker = 0;
-	namespace_list = gee_array_list_new (TYPE_XML_NAMESPACE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal);
+	namespace_list = gee_array_list_new (TYPE_XML_NAMESPACE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal);
 	{
 		gint i;
 		i = 0;
@@ -1198,7 +1191,7 @@ static GObject * gtkaml_sax_parser_constructor (GType type, guint n_construct_pr
 		gtkaml_sax_parser_set_states (self, (_tmp0 = gtkaml_state_stack_new ()));
 		(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
 		_tmp1 = NULL;
-		gtkaml_sax_parser_set_prefixes_namespaces (self, GEE_MAP ((_tmp1 = gee_hash_map_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, g_str_hash, g_str_equal, g_str_equal))));
+		gtkaml_sax_parser_set_prefixes_namespaces (self, GEE_MAP ((_tmp1 = gee_hash_map_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_str_hash, g_str_equal, g_str_equal))));
 		(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
 		gtkaml_sax_parser_set_root_class_definition (self, NULL);
 	}
@@ -1253,10 +1246,10 @@ static void gtkaml_sax_parser_class_init (GtkamlSAXParserClass * klass) {
 }
 
 
-static void gtkaml_sax_parser_init (GtkamlSAXParser * self) {
+static void gtkaml_sax_parser_instance_init (GtkamlSAXParser * self) {
 	self->priv = GTKAML_SAX_PARSER_GET_PRIVATE (self);
-	self->priv->generated_identifiers_counter = GEE_MAP (gee_hash_map_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, G_TYPE_INT, NULL, NULL, g_str_hash, g_str_equal, g_direct_equal));
-	self->priv->used_identifiers = GEE_COLLECTION (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, g_str_equal));
+	self->priv->generated_identifiers_counter = GEE_MAP (gee_hash_map_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, G_TYPE_INT, NULL, NULL, g_str_hash, g_str_equal, g_direct_equal));
+	self->priv->used_identifiers = GEE_COLLECTION (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_str_equal));
 	self->gtkaml_prefix = g_strdup ("gtkaml");
 }
 
@@ -1278,7 +1271,7 @@ static void gtkaml_sax_parser_dispose (GObject * obj) {
 GType gtkaml_sax_parser_get_type (void) {
 	static GType gtkaml_sax_parser_type_id = 0;
 	if (G_UNLIKELY (gtkaml_sax_parser_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GtkamlSAXParserClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_sax_parser_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlSAXParser), 0, (GInstanceInitFunc) gtkaml_sax_parser_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GtkamlSAXParserClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_sax_parser_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlSAXParser), 0, (GInstanceInitFunc) gtkaml_sax_parser_instance_init };
 		gtkaml_sax_parser_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlSAXParser", &g_define_type_info, 0);
 	}
 	return gtkaml_sax_parser_type_id;
@@ -1290,12 +1283,12 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 		int i;
 		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) array)[i] != NULL)
-			destroy_func (((gpointer*) array)[i]);
+			if (((gpointer*) (array))[i] != NULL)
+			destroy_func (((gpointer*) (array))[i]);
 		}
 		else
-		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) array)[i]);
+		for (i = 0; ((gpointer*) (array))[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) (array))[i]);
 		}
 	}
 	g_free (array);
