@@ -50,7 +50,7 @@ GtkamlSimpleAttribute* gtkaml_simple_attribute_new (const char* name, const char
 }
 
 
-char* gtkaml_simple_attribute_get_value (GtkamlSimpleAttribute* self) {
+const char* gtkaml_simple_attribute_get_value (GtkamlSimpleAttribute* self) {
 	g_return_val_if_fail (GTKAML_IS_SIMPLE_ATTRIBUTE (self), NULL);
 	return self->priv->_value;
 }
@@ -104,7 +104,7 @@ static void gtkaml_simple_attribute_class_init (GtkamlSimpleAttributeClass * kla
 }
 
 
-static void gtkaml_simple_attribute_init (GtkamlSimpleAttribute * self) {
+static void gtkaml_simple_attribute_instance_init (GtkamlSimpleAttribute * self) {
 	self->priv = GTKAML_SIMPLE_ATTRIBUTE_GET_PRIVATE (self);
 }
 
@@ -120,7 +120,7 @@ static void gtkaml_simple_attribute_dispose (GObject * obj) {
 GType gtkaml_simple_attribute_get_type (void) {
 	static GType gtkaml_simple_attribute_type_id = 0;
 	if (G_UNLIKELY (gtkaml_simple_attribute_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GtkamlSimpleAttributeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_simple_attribute_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlSimpleAttribute), 0, (GInstanceInitFunc) gtkaml_simple_attribute_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GtkamlSimpleAttributeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_simple_attribute_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlSimpleAttribute), 0, (GInstanceInitFunc) gtkaml_simple_attribute_instance_init };
 		gtkaml_simple_attribute_type_id = g_type_register_static (GTKAML_TYPE_ATTRIBUTE, "GtkamlSimpleAttribute", &g_define_type_info, 0);
 	}
 	return gtkaml_simple_attribute_type_id;
