@@ -113,7 +113,7 @@ void gtkaml_state_set_attribute (GtkamlState* self, GtkamlAttribute* value) {
 }
 
 
-char* gtkaml_state_get_attribute_name (GtkamlState* self) {
+const char* gtkaml_state_get_attribute_name (GtkamlState* self) {
 	g_return_val_if_fail (GTKAML_IS_STATE (self), NULL);
 	return self->priv->_attribute_name;
 }
@@ -188,7 +188,7 @@ static void gtkaml_state_class_init (GtkamlStateClass * klass) {
 }
 
 
-static void gtkaml_state_init (GtkamlState * self) {
+static void gtkaml_state_instance_init (GtkamlState * self) {
 	self->priv = GTKAML_STATE_GET_PRIVATE (self);
 }
 
@@ -206,7 +206,7 @@ static void gtkaml_state_dispose (GObject * obj) {
 GType gtkaml_state_get_type (void) {
 	static GType gtkaml_state_type_id = 0;
 	if (G_UNLIKELY (gtkaml_state_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GtkamlStateClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_state_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlState), 0, (GInstanceInitFunc) gtkaml_state_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GtkamlStateClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gtkaml_state_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GtkamlState), 0, (GInstanceInitFunc) gtkaml_state_instance_init };
 		gtkaml_state_type_id = g_type_register_static (G_TYPE_OBJECT, "GtkamlState", &g_define_type_info, 0);
 	}
 	return gtkaml_state_type_id;
